@@ -314,6 +314,10 @@ ZEND_BEGIN_ARG_INFO_EX(arginfo_swoole_hashcode, 0, 0, 1)
     ZEND_ARG_INFO(0, type)
 ZEND_END_ARG_INFO()
 
+ZEND_BEGIN_ARG_INFO_EX(arginfo_swoole_get_mime_type, 0, 0, 1)
+    ZEND_ARG_INFO(0, filename)
+ZEND_END_ARG_INFO()
+
 ZEND_BEGIN_ARG_INFO_EX(arginfo_swoole_connection_iterator_offsetExists, 0, 0, 1)
     ZEND_ARG_INFO(0, fd)
 ZEND_END_ARG_INFO()
@@ -336,6 +340,7 @@ ZEND_END_ARG_INFO()
 #include "zend_exceptions.h"
 
 static PHP_FUNCTION(swoole_last_error);
+static PHP_FUNCTION(swoole_get_mime_type);
 static PHP_FUNCTION(swoole_hashcode);
 
 const zend_function_entry swoole_functions[] =
@@ -381,13 +386,14 @@ const zend_function_entry swoole_functions[] =
     PHP_FE(swoole_strerror, arginfo_swoole_strerror)
     PHP_FE(swoole_errno, arginfo_swoole_void)
     PHP_FE(swoole_hashcode, arginfo_swoole_hashcode)
+    PHP_FE(swoole_get_mime_type, arginfo_swoole_get_mime_type)
     PHP_FE(swoole_call_user_shutdown_begin, arginfo_swoole_void)
     PHP_FE_END /* Must be the last line in swoole_functions[] */
 };
 
 static zend_function_entry swoole_server_methods[] = {
-    PHP_ME(swoole_server, __construct, arginfo_swoole_server__construct, ZEND_ACC_PUBLIC | ZEND_ACC_CTOR)
-    PHP_ME(swoole_server, __destruct, arginfo_swoole_void, ZEND_ACC_PUBLIC | ZEND_ACC_DTOR)
+    PHP_ME(swoole_server, __construct, arginfo_swoole_server__construct, ZEND_ACC_PUBLIC)
+    PHP_ME(swoole_server, __destruct, arginfo_swoole_void, ZEND_ACC_PUBLIC)
     PHP_ME(swoole_server, listen, arginfo_swoole_server_listen, ZEND_ACC_PUBLIC)
     PHP_MALIAS(swoole_server, addlistener, listen, arginfo_swoole_server_listen, ZEND_ACC_PUBLIC)
     PHP_ME(swoole_server, on, arginfo_swoole_server_on, ZEND_ACC_PUBLIC)
@@ -447,7 +453,7 @@ static const zend_function_entry swoole_connection_iterator_methods[] =
     PHP_ME(swoole_connection_iterator, key,         arginfo_swoole_void, ZEND_ACC_PUBLIC)
     PHP_ME(swoole_connection_iterator, valid,       arginfo_swoole_void, ZEND_ACC_PUBLIC)
     PHP_ME(swoole_connection_iterator, count,       arginfo_swoole_void, ZEND_ACC_PUBLIC)
-    PHP_ME(swoole_connection_iterator, __destruct,  arginfo_swoole_void, ZEND_ACC_PUBLIC | ZEND_ACC_DTOR)
+    PHP_ME(swoole_connection_iterator, __destruct,  arginfo_swoole_void, ZEND_ACC_PUBLIC)
     PHP_ME(swoole_connection_iterator, offsetExists,    arginfo_swoole_connection_iterator_offsetExists, ZEND_ACC_PUBLIC)
     PHP_ME(swoole_connection_iterator, offsetGet,       arginfo_swoole_connection_iterator_offsetGet, ZEND_ACC_PUBLIC)
     PHP_ME(swoole_connection_iterator, offsetSet,       arginfo_swoole_connection_iterator_offsetSet, ZEND_ACC_PUBLIC)
@@ -584,7 +590,7 @@ static void php_swoole_init_globals(zend_swoole_globals *swoole_globals)
     swoole_globals->rshutdown_functions = NULL;
 }
 
-int php_swoole_length_func(swProtocol *protocol, swConnection *conn, char *data, uint32_t length)
+ssize_t php_swoole_length_func(swProtocol *protocol, swConnection *conn, char *data, uint32_t length)
 {
     SwooleG.lock.lock(&SwooleG.lock);
 
@@ -592,29 +598,29 @@ int php_swoole_length_func(swProtocol *protocol, swConnection *conn, char *data,
     zval *retval = NULL;
 
     SW_MAKE_STD_ZVAL(zdata);
-    SW_ZVAL_STRINGL(zdata, data, length, 1);
+    ZVAL_STRINGL(zdata, data, length);
 
-    zval **args[1];
-    args[0] = &zdata;
+    zval args[1];
+    args[0] = *zdata;
 
     zval *callback = protocol->private_data;
 
-    if (sw_call_user_function_ex(EG(function_table), NULL, callback, &retval, 1, args, 0, NULL TSRMLS_CC) == FAILURE)
+    if (sw_call_user_function_ex(EG(function_table), NULL, callback, &retval, 1, args, 0, NULL) == FAILURE)
     {
         swoole_php_fatal_error(E_WARNING, "length function handler error.");
         goto error;
     }
     if (EG(exception))
     {
-        zend_exception_error(EG(exception), E_ERROR TSRMLS_CC);
+        zend_exception_error(EG(exception), E_ERROR);
         goto error;
     }
-    sw_zval_ptr_dtor(&zdata);
+    zval_ptr_dtor(zdata);
     if (retval != NULL)
     {
         convert_to_long(retval);
         int length = Z_LVAL_P(retval);
-        sw_zval_ptr_dtor(&retval);
+        zval_ptr_dtor(retval);
         SwooleG.lock.unlock(&SwooleG.lock);
         return length;
     }
@@ -635,7 +641,7 @@ int php_swoole_dispatch_func(swServer *serv, swConnection *conn, swEventData *da
     zval *retval = NULL;
 
     SW_MAKE_STD_ZVAL(zdata);
-    SW_ZVAL_STRINGL(zdata, data->data, data->info.len, 1);
+    ZVAL_STRINGL(zdata, data->data, data->info.len);
 
     SW_MAKE_STD_ZVAL(zfd);
     ZVAL_LONG(zfd, (long ) conn->session_id);
@@ -643,26 +649,26 @@ int php_swoole_dispatch_func(swServer *serv, swConnection *conn, swEventData *da
     SW_MAKE_STD_ZVAL(ztype);
     ZVAL_LONG(ztype, (long ) data->info.type);
 
-    zval **args[4];
-    args[0] = &zserv;
-    args[1] = &zfd;
-    args[2] = &ztype;
-    args[3] = &zdata;
+    zval args[4];
+    args[0] = *zserv;
+    args[1] = *zfd;
+    args[2] = *ztype;
+    args[3] = *zdata;
 
     zval *callback = (zval*) serv->private_data_3;
-    if (sw_call_user_function_ex(EG(function_table), NULL, callback, &retval, 4, args, 0, NULL TSRMLS_CC) == FAILURE)
+    if (sw_call_user_function_ex(EG(function_table), NULL, callback, &retval, 4, args, 0, NULL) == FAILURE)
     {
         swoole_php_fatal_error(E_WARNING, "dispatch function handler error.");
         goto error;
     }
     if (EG(exception))
     {
-        zend_exception_error(EG(exception), E_ERROR TSRMLS_CC);
+        zend_exception_error(EG(exception), E_ERROR);
         goto error;
     }
-    sw_zval_ptr_dtor(&zfd);
-    sw_zval_ptr_dtor(&ztype);
-    sw_zval_ptr_dtor(&zdata);
+    zval_ptr_dtor(zfd);
+    zval_ptr_dtor(ztype);
+    zval_ptr_dtor(zdata);
     if (retval != NULL)
     {
         convert_to_long(retval);
@@ -672,7 +678,7 @@ int php_swoole_dispatch_func(swServer *serv, swConnection *conn, swEventData *da
             swoole_php_fatal_error(E_WARNING, "invalid target worker-id[%d].", worker_id);
             goto error;
         }
-        sw_zval_ptr_dtor(&retval);
+        zval_ptr_dtor(retval);
         SwooleG.lock.unlock(&SwooleG.lock);
         return worker_id;
     }
@@ -681,7 +687,7 @@ int php_swoole_dispatch_func(swServer *serv, swConnection *conn, swEventData *da
     return -1;
 }
 
-static sw_inline uint32_t swoole_get_new_size(uint32_t old_size, int handle TSRMLS_DC)
+static sw_inline uint32_t swoole_get_new_size(uint32_t old_size, int handle)
 {
     uint32_t new_size = old_size * 2;
     if (handle > SWOOLE_OBJECT_MAX)
@@ -702,12 +708,12 @@ static sw_inline uint32_t swoole_get_new_size(uint32_t old_size, int handle TSRM
 
 void swoole_set_object(zval *object, void *ptr)
 {
-    int handle = sw_get_object_handle(object);
+    int handle = Z_OBJ_HANDLE_P(object);
     assert(handle < SWOOLE_OBJECT_MAX);
     if (handle >= swoole_objects.size)
     {
         uint32_t old_size = swoole_objects.size;
-        uint32_t new_size = swoole_get_new_size(old_size, handle TSRMLS_CC);
+        uint32_t new_size = swoole_get_new_size(old_size, handle);
 
         void *old_ptr = swoole_objects.array;
         void *new_ptr = NULL;
@@ -727,7 +733,7 @@ void swoole_set_object(zval *object, void *ptr)
 
 void swoole_set_property(zval *object, int property_id, void *ptr)
 {
-    int handle = sw_get_object_handle(object);
+    int handle = Z_OBJ_HANDLE_P(object);
     assert(handle < SWOOLE_OBJECT_MAX);
 
     if (handle >= swoole_objects.property_size[property_id])
@@ -745,7 +751,7 @@ void swoole_set_property(zval *object, int property_id, void *ptr)
         }
         else
         {
-            new_size = swoole_get_new_size(old_size, handle TSRMLS_CC);
+            new_size = swoole_get_new_size(old_size, handle);
             old_ptr = swoole_objects.property[property_id];
             new_ptr = realloc(old_ptr, new_size * sizeof(void *));
         }
@@ -892,7 +898,7 @@ PHP_MINIT_FUNCTION(swoole)
     REGISTER_LONG_CONSTANT("SWOOLE_EVENT_READ", SW_EVENT_READ, CONST_CS | CONST_PERSISTENT);
     REGISTER_LONG_CONSTANT("SWOOLE_EVENT_WRITE", SW_EVENT_WRITE, CONST_CS | CONST_PERSISTENT);
 
-    REGISTER_STRINGL_CONSTANT("SWOOLE_VERSION", PHP_SWOOLE_VERSION, sizeof(PHP_SWOOLE_VERSION) - 1, CONST_CS | CONST_PERSISTENT);
+    REGISTER_STRINGL_CONSTANT("SWOOLE_VERSION", SWOOLE_VERSION, sizeof(SWOOLE_VERSION) - 1, CONST_CS | CONST_PERSISTENT);
 
     SWOOLE_DEFINE(ERROR_MALLOC_FAIL);
     SWOOLE_DEFINE(ERROR_SYSTEM_CALL_FAIL);
@@ -992,73 +998,73 @@ PHP_MINIT_FUNCTION(swoole)
     SWOOLE_DEFINE(IPC_SOCKET);
 
     SWOOLE_INIT_CLASS_ENTRY(swoole_server_ce, "swoole_server", "Swoole\\Server", swoole_server_methods);
-    swoole_server_class_entry_ptr = zend_register_internal_class(&swoole_server_ce TSRMLS_CC);
+    swoole_server_class_entry_ptr = zend_register_internal_class(&swoole_server_ce);
     swoole_server_class_entry_ptr->serialize = zend_class_serialize_deny;
     swoole_server_class_entry_ptr->unserialize = zend_class_unserialize_deny;
     SWOOLE_CLASS_ALIAS(swoole_server, "Swoole\\Server");
 
     if (!SWOOLE_G(use_shortname))
     {
-        sw_zend_hash_del(CG(function_table), ZEND_STRS("go"));
+        zend_hash_str_del(CG(function_table), ZEND_STRL("go"));
     }
     else
     {
         sw_zend_register_class_alias("Co\\Server", swoole_server_class_entry_ptr);
     }
 
-    zend_declare_property_null(swoole_server_class_entry_ptr, ZEND_STRL("onConnect"), ZEND_ACC_PUBLIC TSRMLS_CC);
-    zend_declare_property_null(swoole_server_class_entry_ptr, ZEND_STRL("onReceive"), ZEND_ACC_PUBLIC TSRMLS_CC);
-    zend_declare_property_null(swoole_server_class_entry_ptr, ZEND_STRL("onClose"), ZEND_ACC_PUBLIC TSRMLS_CC);
-    zend_declare_property_null(swoole_server_class_entry_ptr, ZEND_STRL("onPacket"), ZEND_ACC_PUBLIC TSRMLS_CC);
-    zend_declare_property_null(swoole_server_class_entry_ptr, ZEND_STRL("onBufferFull"), ZEND_ACC_PUBLIC TSRMLS_CC);
-    zend_declare_property_null(swoole_server_class_entry_ptr, ZEND_STRL("onBufferEmpty"), ZEND_ACC_PUBLIC TSRMLS_CC);
-    zend_declare_property_null(swoole_server_class_entry_ptr, ZEND_STRL("onStart"), ZEND_ACC_PUBLIC TSRMLS_CC);
-    zend_declare_property_null(swoole_server_class_entry_ptr, ZEND_STRL("onShutdown"), ZEND_ACC_PUBLIC TSRMLS_CC);
-    zend_declare_property_null(swoole_server_class_entry_ptr, ZEND_STRL("onWorkerStart"), ZEND_ACC_PUBLIC TSRMLS_CC);
-    zend_declare_property_null(swoole_server_class_entry_ptr, ZEND_STRL("onWorkerStop"), ZEND_ACC_PUBLIC TSRMLS_CC);
-    zend_declare_property_null(swoole_server_class_entry_ptr, ZEND_STRL("onWorkerExit"), ZEND_ACC_PUBLIC TSRMLS_CC);
-    zend_declare_property_null(swoole_server_class_entry_ptr, ZEND_STRL("onWorkerError"), ZEND_ACC_PUBLIC TSRMLS_CC);
-    zend_declare_property_null(swoole_server_class_entry_ptr, ZEND_STRL("onTask"), ZEND_ACC_PUBLIC TSRMLS_CC);
-    zend_declare_property_null(swoole_server_class_entry_ptr, ZEND_STRL("onFinish"), ZEND_ACC_PUBLIC TSRMLS_CC);
-    zend_declare_property_null(swoole_server_class_entry_ptr, ZEND_STRL("onManagerStart"), ZEND_ACC_PUBLIC TSRMLS_CC);
-    zend_declare_property_null(swoole_server_class_entry_ptr, ZEND_STRL("onManagerStop"), ZEND_ACC_PUBLIC TSRMLS_CC);
-    zend_declare_property_null(swoole_server_class_entry_ptr, ZEND_STRL("onPipeMessage"), ZEND_ACC_PUBLIC TSRMLS_CC);
+    zend_declare_property_null(swoole_server_class_entry_ptr, ZEND_STRL("onConnect"), ZEND_ACC_PUBLIC);
+    zend_declare_property_null(swoole_server_class_entry_ptr, ZEND_STRL("onReceive"), ZEND_ACC_PUBLIC);
+    zend_declare_property_null(swoole_server_class_entry_ptr, ZEND_STRL("onClose"), ZEND_ACC_PUBLIC);
+    zend_declare_property_null(swoole_server_class_entry_ptr, ZEND_STRL("onPacket"), ZEND_ACC_PUBLIC);
+    zend_declare_property_null(swoole_server_class_entry_ptr, ZEND_STRL("onBufferFull"), ZEND_ACC_PUBLIC);
+    zend_declare_property_null(swoole_server_class_entry_ptr, ZEND_STRL("onBufferEmpty"), ZEND_ACC_PUBLIC);
+    zend_declare_property_null(swoole_server_class_entry_ptr, ZEND_STRL("onStart"), ZEND_ACC_PUBLIC);
+    zend_declare_property_null(swoole_server_class_entry_ptr, ZEND_STRL("onShutdown"), ZEND_ACC_PUBLIC);
+    zend_declare_property_null(swoole_server_class_entry_ptr, ZEND_STRL("onWorkerStart"), ZEND_ACC_PUBLIC);
+    zend_declare_property_null(swoole_server_class_entry_ptr, ZEND_STRL("onWorkerStop"), ZEND_ACC_PUBLIC);
+    zend_declare_property_null(swoole_server_class_entry_ptr, ZEND_STRL("onWorkerExit"), ZEND_ACC_PUBLIC);
+    zend_declare_property_null(swoole_server_class_entry_ptr, ZEND_STRL("onWorkerError"), ZEND_ACC_PUBLIC);
+    zend_declare_property_null(swoole_server_class_entry_ptr, ZEND_STRL("onTask"), ZEND_ACC_PUBLIC);
+    zend_declare_property_null(swoole_server_class_entry_ptr, ZEND_STRL("onFinish"), ZEND_ACC_PUBLIC);
+    zend_declare_property_null(swoole_server_class_entry_ptr, ZEND_STRL("onManagerStart"), ZEND_ACC_PUBLIC);
+    zend_declare_property_null(swoole_server_class_entry_ptr, ZEND_STRL("onManagerStop"), ZEND_ACC_PUBLIC);
+    zend_declare_property_null(swoole_server_class_entry_ptr, ZEND_STRL("onPipeMessage"), ZEND_ACC_PUBLIC);
 
-    zend_declare_property_null(swoole_server_class_entry_ptr, ZEND_STRL("setting"), ZEND_ACC_PUBLIC TSRMLS_CC);
-    zend_declare_property_null(swoole_server_class_entry_ptr, ZEND_STRL("connections"), ZEND_ACC_PUBLIC TSRMLS_CC);
-    zend_declare_property_null(swoole_server_class_entry_ptr, ZEND_STRL("host"), ZEND_ACC_PUBLIC TSRMLS_CC);
-    zend_declare_property_long(swoole_server_class_entry_ptr, ZEND_STRL("port"), 0, ZEND_ACC_PUBLIC TSRMLS_CC);
-    zend_declare_property_long(swoole_server_class_entry_ptr, ZEND_STRL("type"), 0, ZEND_ACC_PUBLIC TSRMLS_CC);
-    zend_declare_property_long(swoole_server_class_entry_ptr, ZEND_STRL("mode"), 0, ZEND_ACC_PUBLIC TSRMLS_CC);
-    zend_declare_property_null(swoole_server_class_entry_ptr, ZEND_STRL("ports"), ZEND_ACC_PUBLIC TSRMLS_CC);
-    zend_declare_property_long(swoole_server_class_entry_ptr, ZEND_STRL("master_pid"), 0, ZEND_ACC_PUBLIC TSRMLS_CC);
-    zend_declare_property_long(swoole_server_class_entry_ptr, ZEND_STRL("manager_pid"), 0, ZEND_ACC_PUBLIC TSRMLS_CC);
-    zend_declare_property_long(swoole_server_class_entry_ptr, ZEND_STRL("worker_id"), -1, ZEND_ACC_PUBLIC TSRMLS_CC);
-    zend_declare_property_bool(swoole_server_class_entry_ptr, ZEND_STRL("taskworker"), 0, ZEND_ACC_PUBLIC TSRMLS_CC);
-    zend_declare_property_long(swoole_server_class_entry_ptr, ZEND_STRL("worker_pid"), 0, ZEND_ACC_PUBLIC TSRMLS_CC);
+    zend_declare_property_null(swoole_server_class_entry_ptr, ZEND_STRL("setting"), ZEND_ACC_PUBLIC);
+    zend_declare_property_null(swoole_server_class_entry_ptr, ZEND_STRL("connections"), ZEND_ACC_PUBLIC);
+    zend_declare_property_null(swoole_server_class_entry_ptr, ZEND_STRL("host"), ZEND_ACC_PUBLIC);
+    zend_declare_property_long(swoole_server_class_entry_ptr, ZEND_STRL("port"), 0, ZEND_ACC_PUBLIC);
+    zend_declare_property_long(swoole_server_class_entry_ptr, ZEND_STRL("type"), 0, ZEND_ACC_PUBLIC);
+    zend_declare_property_long(swoole_server_class_entry_ptr, ZEND_STRL("mode"), 0, ZEND_ACC_PUBLIC);
+    zend_declare_property_null(swoole_server_class_entry_ptr, ZEND_STRL("ports"), ZEND_ACC_PUBLIC);
+    zend_declare_property_long(swoole_server_class_entry_ptr, ZEND_STRL("master_pid"), 0, ZEND_ACC_PUBLIC);
+    zend_declare_property_long(swoole_server_class_entry_ptr, ZEND_STRL("manager_pid"), 0, ZEND_ACC_PUBLIC);
+    zend_declare_property_long(swoole_server_class_entry_ptr, ZEND_STRL("worker_id"), -1, ZEND_ACC_PUBLIC);
+    zend_declare_property_bool(swoole_server_class_entry_ptr, ZEND_STRL("taskworker"), 0, ZEND_ACC_PUBLIC);
+    zend_declare_property_long(swoole_server_class_entry_ptr, ZEND_STRL("worker_pid"), 0, ZEND_ACC_PUBLIC);
 
     SWOOLE_INIT_CLASS_ENTRY(swoole_timer_ce, "swoole_timer", "Swoole\\Timer", swoole_timer_methods);
-    swoole_timer_class_entry_ptr = zend_register_internal_class(&swoole_timer_ce TSRMLS_CC);
+    swoole_timer_class_entry_ptr = zend_register_internal_class(&swoole_timer_ce);
     SWOOLE_CLASS_ALIAS(swoole_timer, "Swoole\\Timer");
 
     SWOOLE_INIT_CLASS_ENTRY(swoole_event_ce, "swoole_event", "Swoole\\Event", swoole_event_methods);
-    swoole_event_class_entry_ptr = zend_register_internal_class(&swoole_event_ce TSRMLS_CC);
+    swoole_event_class_entry_ptr = zend_register_internal_class(&swoole_event_ce);
     SWOOLE_CLASS_ALIAS(swoole_event, "Swoole\\Event");
 
     SWOOLE_INIT_CLASS_ENTRY(swoole_async_ce, "swoole_async", "Swoole\\Async", swoole_async_methods);
-    swoole_async_class_entry_ptr = zend_register_internal_class(&swoole_async_ce TSRMLS_CC);
+    swoole_async_class_entry_ptr = zend_register_internal_class(&swoole_async_ce);
     SWOOLE_CLASS_ALIAS(swoole_async, "Swoole\\Async");
 
     SWOOLE_INIT_CLASS_ENTRY(swoole_connection_iterator_ce, "swoole_connection_iterator", "Swoole\\Connection\\Iterator",  swoole_connection_iterator_methods);
-    swoole_connection_iterator_class_entry_ptr = zend_register_internal_class(&swoole_connection_iterator_ce TSRMLS_CC);
+    swoole_connection_iterator_class_entry_ptr = zend_register_internal_class(&swoole_connection_iterator_ce);
     SWOOLE_CLASS_ALIAS(swoole_connection_iterator, "Swoole\\Connection\\Iterator");
-    zend_class_implements(swoole_connection_iterator_class_entry_ptr TSRMLS_CC, 2, zend_ce_iterator, zend_ce_arrayaccess);
+    zend_class_implements(swoole_connection_iterator_class_entry_ptr, 2, zend_ce_iterator, zend_ce_arrayaccess);
 #ifdef SW_HAVE_COUNTABLE
-    zend_class_implements(swoole_connection_iterator_class_entry_ptr TSRMLS_CC, 1, zend_ce_countable);
+    zend_class_implements(swoole_connection_iterator_class_entry_ptr, 1, zend_ce_countable);
 #endif
 
     SWOOLE_INIT_CLASS_ENTRY(swoole_exception_ce, "swoole_exception", "Swoole\\Exception", NULL);
-    swoole_exception_class_entry_ptr = sw_zend_register_internal_class_ex(&swoole_exception_ce, zend_exception_get_default(TSRMLS_C), NULL TSRMLS_CC);
+    swoole_exception_class_entry_ptr = sw_zend_register_internal_class_ex(&swoole_exception_ce, zend_exception_get_default(), NULL);
     SWOOLE_CLASS_ALIAS(swoole_exception, "Swoole\\Exception");
 
     //swoole init
@@ -1072,53 +1078,53 @@ PHP_MINIT_FUNCTION(swoole)
         SWOOLE_G(cli) = 1;
     }
 
-    swoole_server_port_init(module_number TSRMLS_CC);
-    swoole_client_init(module_number TSRMLS_CC);
+    swoole_server_port_init(module_number);
+    swoole_client_init(module_number);
 #ifdef SW_COROUTINE
-    swoole_socket_coro_init(module_number TSRMLS_CC);
-    swoole_client_coro_init(module_number TSRMLS_CC);
+    swoole_socket_coro_init(module_number);
+    swoole_client_coro_init(module_number);
 #ifdef SW_USE_REDIS
-    swoole_redis_coro_init(module_number TSRMLS_CC);
+    swoole_redis_coro_init(module_number);
 #endif
 #ifdef SW_USE_POSTGRESQL
-    swoole_postgresql_coro_init(module_number TSRMLS_CC);
+    swoole_postgresql_coro_init(module_number);
 #endif
-    swoole_mysql_coro_init(module_number TSRMLS_CC);
-    swoole_http_client_coro_init(module_number TSRMLS_CC);
-	swoole_coroutine_util_init(module_number TSRMLS_CC);
+    swoole_mysql_coro_init(module_number);
+    swoole_http_client_coro_init(module_number);
+	swoole_coroutine_util_init(module_number);
 #endif
-    swoole_http_client_init(module_number TSRMLS_CC);
-    swoole_async_init(module_number TSRMLS_CC);
-    swoole_process_init(module_number TSRMLS_CC);
-    swoole_process_pool_init(module_number TSRMLS_CC);
-    swoole_table_init(module_number TSRMLS_CC);
-    swoole_runtime_init(module_number TSRMLS_CC);
-    swoole_lock_init(module_number TSRMLS_CC);
-    swoole_atomic_init(module_number TSRMLS_CC);
-    swoole_http_server_init(module_number TSRMLS_CC);
-    swoole_buffer_init(module_number TSRMLS_CC);
-    swoole_websocket_init(module_number TSRMLS_CC);
-    swoole_mysql_init(module_number TSRMLS_CC);
-    swoole_mmap_init(module_number TSRMLS_CC);
-    swoole_channel_init(module_number TSRMLS_CC);
+    swoole_http_client_init(module_number);
+    swoole_async_init(module_number);
+    swoole_process_init(module_number);
+    swoole_process_pool_init(module_number);
+    swoole_table_init(module_number);
+    swoole_runtime_init(module_number);
+    swoole_lock_init(module_number);
+    swoole_atomic_init(module_number);
+    swoole_http_server_init(module_number);
+    swoole_buffer_init(module_number);
+    swoole_websocket_init(module_number);
+    swoole_mysql_init(module_number);
+    swoole_mmap_init(module_number);
+    swoole_channel_init(module_number);
 #ifdef SW_COROUTINE
-    swoole_channel_coro_init(module_number TSRMLS_CC);
+    swoole_channel_coro_init(module_number);
 #endif
-    swoole_ringqueue_init(module_number TSRMLS_CC);
-    swoole_msgqueue_init(module_number TSRMLS_CC);
+    swoole_ringqueue_init(module_number);
+    swoole_msgqueue_init(module_number);
 #ifdef SW_USE_HTTP2
 #ifdef SW_COROUTINE
-    swoole_http2_client_coro_init(module_number TSRMLS_CC);
+    swoole_http2_client_coro_init(module_number);
 #endif
 #endif
 
-    swoole_serialize_init(module_number TSRMLS_DC);
-    swoole_memory_pool_init(module_number TSRMLS_DC);
+    swoole_serialize_init(module_number);
+    swoole_memory_pool_init(module_number);
 
 #ifdef SW_USE_REDIS
-    swoole_redis_init(module_number TSRMLS_CC);
+    swoole_redis_init(module_number);
 #endif
-    swoole_redis_server_init(module_number TSRMLS_CC);
+    swoole_redis_server_init(module_number);
 
     if (SWOOLE_G(socket_buffer_size) > 0)
     {
@@ -1166,7 +1172,7 @@ PHP_MINFO_FUNCTION(swoole)
 {
     php_info_print_table_start();
     php_info_print_table_header(2, "swoole support", "enabled");
-    php_info_print_table_row(2, "Version", PHP_SWOOLE_VERSION);
+    php_info_print_table_row(2, "Version", SWOOLE_VERSION);
     php_info_print_table_row(2, "Author", "Swoole Group[email: team@swoole.com]");
 
 #ifdef SW_COROUTINE
@@ -1176,7 +1182,7 @@ PHP_MINFO_FUNCTION(swoole)
     php_info_print_table_row(2, "debug", "enabled");
 #endif
 #ifdef SW_LOG_TRACE_OPEN
-    php_info_print_table_row(2, "trace-log", "enabled");
+    php_info_print_table_row(2, "trace_log", "enabled");
 #endif
 #if USE_BOOST_CONTEXT
     php_info_print_table_row(2, "boost.context", "enabled");
@@ -1200,7 +1206,7 @@ PHP_MINFO_FUNCTION(swoole)
     php_info_print_table_row(2, "accept4", "enabled");
 #endif
 #ifdef HAVE_CPU_AFFINITY
-    php_info_print_table_row(2, "cpu affinity", "enabled");
+    php_info_print_table_row(2, "cpu_affinity", "enabled");
 #endif
 #ifdef HAVE_SPINLOCK
     php_info_print_table_row(2, "spinlock", "enabled");
@@ -1212,17 +1218,22 @@ PHP_MINFO_FUNCTION(swoole)
     php_info_print_table_row(2, "sockets", "enabled");
 #endif
 #ifdef SW_USE_OPENSSL
+#ifdef OPENSSL_VERSION_TEXT
+    php_info_print_table_row(2, "openssl", OPENSSL_VERSION_TEXT);
+#else
     php_info_print_table_row(2, "openssl", "enabled");
 #endif
+#endif
 #ifdef SW_USE_HTTP2
+#ifdef NGHTTP2_VERSION
+    php_info_print_table_row(2, "http2", NGHTTP2_VERSION);
+#else
     php_info_print_table_row(2, "http2", "enabled");
 #endif
+#endif
 #ifdef SW_USE_RINGBUFFER
     php_info_print_table_row(2, "ringbuffer", "enabled");
 #endif
-#ifdef HAVE_GCC_AIO
-    php_info_print_table_row(2, "GCC AIO", "enabled");
-#endif
 #ifdef HAVE_PCRE
     php_info_print_table_row(2, "pcre", "enabled");
 #endif
@@ -1254,10 +1265,10 @@ PHP_MINFO_FUNCTION(swoole)
     php_info_print_table_row(2, "hugepage", "enabled");
 #endif
 #ifdef SW_USE_REDIS
-    php_info_print_table_row(2, "redis client", "enabled");
+    php_info_print_table_row(2, "async_redis", "enabled");
 #endif
 #ifdef SW_USE_POSTGRESQL
-    php_info_print_table_row(2, "postgresql client", "enabled");
+    php_info_print_table_row(2, "coroutine_postgresql", "enabled");
 #endif
     php_info_print_table_end();
 
@@ -1327,7 +1338,7 @@ PHP_RSHUTDOWN_FUNCTION(swoole)
     SwooleWG.reactor_wait_onexit = 0;
 
 #ifdef SW_COROUTINE
-    coro_destroy(TSRMLS_C);
+    coro_destroy();
 #endif
     SWOOLE_G(req_status) = PHP_SWOOLE_RSHUTDOWN_END;
     return SUCCESS;
@@ -1335,7 +1346,7 @@ PHP_RSHUTDOWN_FUNCTION(swoole)
 
 PHP_FUNCTION(swoole_version)
 {
-    SW_RETURN_STRING(PHP_SWOOLE_VERSION, 1);
+    RETURN_STRING(SWOOLE_VERSION);
 }
 
 static uint32_t hashkit_one_at_a_time(const char *key, size_t key_length)
@@ -1370,7 +1381,7 @@ static PHP_FUNCTION(swoole_hashcode)
         Z_PARAM_LONG(type)
     ZEND_PARSE_PARAMETERS_END();
 #else
-    if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "s|l", &data, &l_data, &type) == FAILURE)
+    if (zend_parse_parameters(ZEND_NUM_ARGS(), "s|l", &data, &l_data, &type) == FAILURE)
     {
         return;
     }
@@ -1406,7 +1417,7 @@ PHP_FUNCTION(swoole_strerror)
     char error_msg[256] = {0};
     long error_type = 0;
 
-    if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "l|l", &swoole_errno, &error_type) == FAILURE)
+    if (zend_parse_parameters(ZEND_NUM_ARGS(), "l|l", &swoole_errno, &error_type) == FAILURE)
     {
         return;
     }
@@ -1422,7 +1433,18 @@ PHP_FUNCTION(swoole_strerror)
     {
         snprintf(error_msg, sizeof(error_msg) - 1, "%s", strerror(swoole_errno));
     }
-    SW_RETURN_STRING(error_msg, 1);
+    RETURN_STRING(error_msg);
+}
+
+PHP_FUNCTION(swoole_get_mime_type)
+{
+    char *filename;
+    zend_long filename_len;
+    if (zend_parse_parameters(ZEND_NUM_ARGS(), "s", &filename, &filename_len) == FAILURE)
+    {
+        return;
+    }
+    RETURN_STRING(swoole_get_mime_type(filename));
 }
 
 PHP_FUNCTION(swoole_errno)
@@ -1434,13 +1456,13 @@ PHP_FUNCTION(swoole_set_process_name)
 {
     // MacOS doesn't support 'cli_set_process_title'
 #ifdef __MACH__
-    php_error_docref(NULL TSRMLS_CC, E_WARNING, "swoole_set_process_name is not supported on MacOS.");
+    php_error_docref(NULL, E_WARNING, "swoole_set_process_name is not supported on MacOS.");
     return;
 #endif
     zval *name;
     long size = 128;
 
-    if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "z|l", &name, &size) == FAILURE)
+    if (zend_parse_parameters(ZEND_NUM_ARGS(), "z|l", &name, &size) == FAILURE)
     {
         return;
     }
@@ -1451,7 +1473,7 @@ PHP_FUNCTION(swoole_set_process_name)
     }
     else if (Z_STRLEN_P(name) > 127)
     {
-        php_error_docref(NULL TSRMLS_CC, E_WARNING, "process name is too long, the max length is 127");
+        php_error_docref(NULL, E_WARNING, "process name is too long, the max length is 127");
     }
 
     if (size > SwooleG.pagesize)
@@ -1460,25 +1482,25 @@ PHP_FUNCTION(swoole_set_process_name)
     }
 
     zval *retval;
-    zval **args[1];
-    args[0] = &name;
+    zval args[1];
+    args[0] = *name;
 
     zval *function;
     SW_MAKE_STD_ZVAL(function);
-    SW_ZVAL_STRING(function, "cli_set_process_title", 1);
+    ZVAL_STRING(function, "cli_set_process_title");
 
-    if (sw_call_user_function_ex(EG(function_table), NULL, function, &retval, 1, args, 0, NULL TSRMLS_CC) == FAILURE)
+    if (sw_call_user_function_ex(EG(function_table), NULL, function, &retval, 1, args, 0, NULL) == FAILURE)
     {
         return;
     }
     if (EG(exception))
     {
-        zend_exception_error(EG(exception), E_ERROR TSRMLS_CC);
+        zend_exception_error(EG(exception), E_ERROR);
     }
-    sw_zval_ptr_dtor(&function);
+    zval_ptr_dtor(function);
     if (retval)
     {
-        sw_zval_ptr_dtor(&retval);
+        zval_ptr_dtor(retval);
     }
 }
 
@@ -1491,7 +1513,7 @@ PHP_FUNCTION(swoole_get_local_ip)
 
     if (getifaddrs(&ipaddrs) != 0)
     {
-        php_error_docref(NULL TSRMLS_CC, E_WARNING, "getifaddrs() failed. Error: %s[%d]", strerror(errno), errno);
+        php_error_docref(NULL, E_WARNING, "getifaddrs() failed. Error: %s[%d]", strerror(errno), errno);
         RETURN_FALSE;
     }
     array_init(return_value);
@@ -1517,7 +1539,7 @@ PHP_FUNCTION(swoole_get_local_ip)
         }
         if (!inet_ntop(ifa->ifa_addr->sa_family, in_addr, ip, sizeof(ip)))
         {
-            php_error_docref(NULL TSRMLS_CC, E_WARNING, "%s: inet_ntop failed.", ifa->ifa_name);
+            php_error_docref(NULL, E_WARNING, "%s: inet_ntop failed.", ifa->ifa_name);
         }
         else
         {
@@ -1526,7 +1548,7 @@ PHP_FUNCTION(swoole_get_local_ip)
             {
                 continue;
             }
-            sw_add_assoc_string(return_value, ifa->ifa_name, ip, 1);
+            add_assoc_string(return_value, ifa->ifa_name, ip);
         }
     }
     freeifaddrs(ipaddrs);
@@ -1544,7 +1566,7 @@ PHP_FUNCTION(swoole_get_local_mac)
 
     if ((sock = socket(AF_INET, SOCK_STREAM, 0)) < 0)
     {
-        php_error_docref(NULL TSRMLS_CC, E_WARNING, "new socket failed. Error: %s[%d]", strerror(errno), errno);
+        php_error_docref(NULL, E_WARNING, "new socket failed. Error: %s[%d]", strerror(errno), errno);
         RETURN_FALSE;
     }
     array_init(return_value);
@@ -1565,14 +1587,14 @@ PHP_FUNCTION(swoole_get_local_mac)
                         (unsigned char) buf[i].ifr_hwaddr.sa_data[3],
                         (unsigned char) buf[i].ifr_hwaddr.sa_data[4],
                         (unsigned char) buf[i].ifr_hwaddr.sa_data[5]);
-                sw_add_assoc_string(return_value, buf[i].ifr_name, mac, 1);
+                add_assoc_string(return_value, buf[i].ifr_name, mac);
             }
             i++;
         }
     }
     close(sock);
 #else
-    php_error_docref(NULL TSRMLS_CC, E_WARNING, "swoole_get_local_mac is not supported.");
+    php_error_docref(NULL, E_WARNING, "swoole_get_local_mac is not supported.");
     RETURN_FALSE;
 #endif
 }
