@@ -30,10 +30,6 @@ enum client_property
 
 using namespace swoole;
 
-#ifdef FAST_ZPP
-#undef FAST_ZPP
-#endif
-
 ZEND_BEGIN_ARG_INFO_EX(arginfo_swoole_client_coro_void, 0, 0, 0)
 ZEND_END_ARG_INFO()
 
@@ -111,8 +107,8 @@ void php_swoole_client_coro_check_setting(Socket *cli, zval *zset);
 
 static const zend_function_entry swoole_client_coro_methods[] =
 {
-    PHP_ME(swoole_client_coro, __construct, arginfo_swoole_client_coro_construct, ZEND_ACC_PUBLIC | ZEND_ACC_CTOR)
-    PHP_ME(swoole_client_coro, __destruct, arginfo_swoole_client_coro_void, ZEND_ACC_PUBLIC | ZEND_ACC_DTOR)
+    PHP_ME(swoole_client_coro, __construct, arginfo_swoole_client_coro_construct, ZEND_ACC_PUBLIC)
+    PHP_ME(swoole_client_coro, __destruct, arginfo_swoole_client_coro_void, ZEND_ACC_PUBLIC)
     PHP_ME(swoole_client_coro, set, arginfo_swoole_client_coro_set, ZEND_ACC_PUBLIC)
     PHP_ME(swoole_client_coro, connect, arginfo_swoole_client_coro_connect, ZEND_ACC_PUBLIC)
     PHP_ME(swoole_client_coro, recv, arginfo_swoole_client_coro_recv, ZEND_ACC_PUBLIC)
@@ -139,10 +135,10 @@ static const zend_function_entry swoole_client_coro_methods[] =
 zend_class_entry swoole_client_coro_ce;
 zend_class_entry *swoole_client_coro_class_entry_ptr;
 
-void swoole_client_coro_init(int module_number TSRMLS_DC)
+void swoole_client_coro_init(int module_number)
 {
     INIT_CLASS_ENTRY(swoole_client_coro_ce, "Swoole\\Coroutine\\Client", swoole_client_coro_methods);
-    swoole_client_coro_class_entry_ptr = zend_register_internal_class(&swoole_client_coro_ce TSRMLS_CC);
+    swoole_client_coro_class_entry_ptr = zend_register_internal_class(&swoole_client_coro_ce);
     swoole_client_coro_class_entry_ptr->serialize = zend_class_serialize_deny;
     swoole_client_coro_class_entry_ptr->unserialize = zend_class_unserialize_deny;
 
@@ -151,19 +147,19 @@ void swoole_client_coro_init(int module_number TSRMLS_DC)
         sw_zend_register_class_alias("Co\\Client", swoole_client_coro_class_entry_ptr);
     }
 
-    zend_declare_property_long(swoole_client_coro_class_entry_ptr, SW_STRL("errCode")-1, 0, ZEND_ACC_PUBLIC TSRMLS_CC);
-    zend_declare_property_long(swoole_client_coro_class_entry_ptr, SW_STRL("sock")-1, 0, ZEND_ACC_PUBLIC TSRMLS_CC);
-    zend_declare_property_long(swoole_client_coro_class_entry_ptr, ZEND_STRL("type"), 0, ZEND_ACC_PUBLIC TSRMLS_CC);
-    zend_declare_property_null(swoole_client_coro_class_entry_ptr, ZEND_STRL("setting"), ZEND_ACC_PUBLIC TSRMLS_CC);
-    zend_declare_property_bool(swoole_client_coro_class_entry_ptr, ZEND_STRL("connected"), 0, ZEND_ACC_PUBLIC TSRMLS_CC);
+    zend_declare_property_long(swoole_client_coro_class_entry_ptr, ZEND_STRL("errCode"), 0, ZEND_ACC_PUBLIC);
+    zend_declare_property_long(swoole_client_coro_class_entry_ptr, ZEND_STRL("sock"), 0, ZEND_ACC_PUBLIC);
+    zend_declare_property_long(swoole_client_coro_class_entry_ptr, ZEND_STRL("type"), 0, ZEND_ACC_PUBLIC);
+    zend_declare_property_null(swoole_client_coro_class_entry_ptr, ZEND_STRL("setting"), ZEND_ACC_PUBLIC);
+    zend_declare_property_bool(swoole_client_coro_class_entry_ptr, ZEND_STRL("connected"), 0, ZEND_ACC_PUBLIC);
 
-    zend_declare_class_constant_long(swoole_client_coro_class_entry_ptr, ZEND_STRL("MSG_OOB"), MSG_OOB TSRMLS_CC);
-    zend_declare_class_constant_long(swoole_client_coro_class_entry_ptr, ZEND_STRL("MSG_PEEK"), MSG_PEEK TSRMLS_CC);
-    zend_declare_class_constant_long(swoole_client_coro_class_entry_ptr, ZEND_STRL("MSG_DONTWAIT"), MSG_DONTWAIT TSRMLS_CC);
-    zend_declare_class_constant_long(swoole_client_coro_class_entry_ptr, ZEND_STRL("MSG_WAITALL"), MSG_WAITALL TSRMLS_CC);
+    zend_declare_class_constant_long(swoole_client_coro_class_entry_ptr, ZEND_STRL("MSG_OOB"), MSG_OOB);
+    zend_declare_class_constant_long(swoole_client_coro_class_entry_ptr, ZEND_STRL("MSG_PEEK"), MSG_PEEK);
+    zend_declare_class_constant_long(swoole_client_coro_class_entry_ptr, ZEND_STRL("MSG_DONTWAIT"), MSG_DONTWAIT);
+    zend_declare_class_constant_long(swoole_client_coro_class_entry_ptr, ZEND_STRL("MSG_WAITALL"), MSG_WAITALL);
 }
 
-static sw_inline Socket* client_get_ptr(zval *zobject TSRMLS_DC)
+static sw_inline Socket* client_get_ptr(zval *zobject)
 {
     Socket *cli = (Socket *) swoole_get_object(zobject);
     if (cli && cli->socket && cli->socket->active == 1)
@@ -173,7 +169,7 @@ static sw_inline Socket* client_get_ptr(zval *zobject TSRMLS_DC)
     else
     {
         SwooleG.error = SW_ERROR_CLIENT_NO_CONNECTION;
-        zend_update_property_long(swoole_client_coro_class_entry_ptr, zobject, SW_STRL("errCode")-1, SwooleG.error TSRMLS_CC);
+        zend_update_property_long(swoole_client_coro_class_entry_ptr, zobject, ZEND_STRL("errCode"), SwooleG.error);
         swoole_php_error(E_WARNING, "client is not connected to server.");
         return NULL;
     }
@@ -183,7 +179,7 @@ static Socket* client_coro_new(zval *object, int port)
 {
     zval *ztype;
 
-    ztype = sw_zend_read_property(Z_OBJCE_P(object), object, SW_STRL("type")-1, 0 TSRMLS_CC);
+    ztype = sw_zend_read_property(Z_OBJCE_P(object), object, ZEND_STRL("type"), 0);
 
     if (ztype == NULL || ZVAL_IS_NULL(ztype))
     {
@@ -202,11 +198,11 @@ static Socket* client_coro_new(zval *object, int port)
     if (!cli)
     {
         swoole_php_fatal_error(E_WARNING, "new Client() failed. Error: %s [%d]", strerror(errno), errno);
-        zend_update_property_long(Z_OBJCE_P(object), object, ZEND_STRL("errCode"), errno TSRMLS_CC);
+        zend_update_property_long(Z_OBJCE_P(object), object, ZEND_STRL("errCode"), errno);
         return NULL;
     }
 
-    zend_update_property_long(Z_OBJCE_P(object), object, ZEND_STRL("sock"), cli->socket->fd TSRMLS_CC);
+    zend_update_property_long(Z_OBJCE_P(object), object, ZEND_STRL("sock"), cli->socket->fd);
 
 #ifdef SW_USE_OPENSSL
     if (type & SW_SOCK_SSL)
@@ -218,7 +214,7 @@ static Socket* client_coro_new(zval *object, int port)
     return cli;
 }
 
-void php_swoole_client_coro_free(zval *zobject, Socket *cli TSRMLS_DC)
+void php_swoole_client_coro_free(zval *zobject, Socket *cli)
 {
     if (cli->timer)
     {
@@ -265,10 +261,10 @@ void php_swoole_client_coro_free(zval *zobject, Socket *cli TSRMLS_DC)
 #endif
     //unset object
     swoole_set_object(zobject, NULL);
-    zend_update_property_bool(Z_OBJCE_P(zobject), zobject, SW_STRL("connected")-1, 0);
+    zend_update_property_bool(Z_OBJCE_P(zobject), zobject, ZEND_STRL("connected"), 0);
 }
 
-void php_swoole_client_coro_check_setting(Socket *cli, zval *zset TSRMLS_DC)
+void php_swoole_client_coro_check_setting(Socket *cli, zval *zset)
 {
     HashTable *vht;
     zval *v;
@@ -352,7 +348,7 @@ void php_swoole_client_coro_check_setting(Socket *cli, zval *zset TSRMLS_DC)
             }
 
             char *func_name = NULL;
-            if (!sw_zend_is_callable(v, 0, &func_name TSRMLS_CC))
+            if (!sw_zend_is_callable(v, 0, &func_name))
             {
                 swoole_php_fatal_error(E_ERROR, "Function '%s' is not callable", func_name);
                 efree(func_name);
@@ -360,7 +356,7 @@ void php_swoole_client_coro_check_setting(Socket *cli, zval *zset TSRMLS_DC)
             }
             efree(func_name);
             cli->protocol.get_package_length = php_swoole_length_func;
-            sw_zval_add_ref(&v);
+            Z_TRY_ADDREF_P(v);
             cli->protocol.private_data = sw_zval_dup(v);
             break;
         }
@@ -619,7 +615,7 @@ static PHP_METHOD(swoole_client_coro, __construct)
 {
     long type = 0;
 
-    if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "l|ls", &type) == FAILURE)
+    if (zend_parse_parameters(ZEND_NUM_ARGS(), "l|ls", &type) == FAILURE)
     {
         swoole_php_fatal_error(E_ERROR, "socket type param is required.");
         RETURN_FALSE;
@@ -633,7 +629,7 @@ static PHP_METHOD(swoole_client_coro, __construct)
 
     php_swoole_check_reactor();
 
-    zend_update_property_long(swoole_client_coro_class_entry_ptr, getThis(), ZEND_STRL("type"), type TSRMLS_CC);
+    zend_update_property_long(swoole_client_coro_class_entry_ptr, getThis(), ZEND_STRL("type"), type);
     //init
     swoole_set_object(getThis(), NULL);
     swoole_set_property(getThis(), client_property_callback, NULL);
@@ -656,7 +652,7 @@ static PHP_METHOD(swoole_client_coro, __destruct)
         sw_zend_call_method_with_0_params(&zobject, swoole_client_coro_class_entry_ptr, NULL, "close", &retval);
         if (retval)
         {
-            sw_zval_ptr_dtor(&retval);
+            zval_ptr_dtor(retval);
         }
     }
 }
@@ -664,7 +660,7 @@ static PHP_METHOD(swoole_client_coro, __destruct)
 static PHP_METHOD(swoole_client_coro, set)
 {
     zval *zset;
-    if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "z", &zset) == FAILURE)
+    if (zend_parse_parameters(ZEND_NUM_ARGS(), "z", &zset) == FAILURE)
     {
         return;
     }
@@ -673,8 +669,8 @@ static PHP_METHOD(swoole_client_coro, set)
         RETURN_FALSE;
     }
 
-    zval *zsetting = php_swoole_read_init_property(swoole_client_coro_class_entry_ptr, getThis(), ZEND_STRL("setting") TSRMLS_CC);
-    sw_php_array_merge(Z_ARRVAL_P(zsetting), Z_ARRVAL_P(zset));
+    zval *zsetting = sw_zend_read_property_array(swoole_client_coro_class_entry_ptr, getThis(), ZEND_STRL("setting"), 1);
+    php_array_merge(Z_ARRVAL_P(zsetting), Z_ARRVAL_P(zset));
 
     RETURN_TRUE;
 }
@@ -686,7 +682,6 @@ static PHP_METHOD(swoole_client_coro, connect)
     zend_size_t host_len;
     double timeout = SW_CLIENT_DEFAULT_TIMEOUT;
 
-#ifdef FAST_ZPP
     ZEND_PARSE_PARAMETERS_START(1, 4)
         Z_PARAM_STRING(host, host_len)
         Z_PARAM_OPTIONAL
@@ -694,12 +689,6 @@ static PHP_METHOD(swoole_client_coro, connect)
         Z_PARAM_DOUBLE(timeout)
         Z_PARAM_LONG(sock_flag)
     ZEND_PARSE_PARAMETERS_END();
-#else
-    if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "s|ldl", &host, &host_len, &port, &timeout, &sock_flag) == FAILURE)
-    {
-        return;
-    }
-#endif
 
     if (host_len <= 0)
     {
@@ -722,7 +711,7 @@ static PHP_METHOD(swoole_client_coro, connect)
     cli->_timeout = timeout;
     swoole_set_object(getThis(), cli);
 
-    zval *zset = sw_zend_read_property(swoole_client_coro_class_entry_ptr, getThis(), ZEND_STRL("setting"), 1 TSRMLS_CC);
+    zval *zset = sw_zend_read_property(swoole_client_coro_class_entry_ptr, getThis(), ZEND_STRL("setting"), 1);
     if (zset && !ZVAL_IS_NULL(zset))
     {
         php_swoole_client_coro_check_setting(cli, zset);
@@ -730,12 +719,12 @@ static PHP_METHOD(swoole_client_coro, connect)
 
     if (!cli->connect(host, port, sock_flag))
     {
-        zend_update_property_long(swoole_client_coro_class_entry_ptr, getThis(), SW_STRL("errCode")-1, cli->errCode);
+        zend_update_property_long(swoole_client_coro_class_entry_ptr, getThis(), ZEND_STRL("errCode"), cli->errCode);
         swoole_php_error(E_WARNING, "connect to server[%s:%d] failed. Error: %s[%d]", host, (int )port, cli->errMsg,
                 cli->errCode);
         RETURN_FALSE;
     }
-    zend_update_property_bool(swoole_client_coro_class_entry_ptr, getThis(), SW_STRL("connected")-1, 1);
+    zend_update_property_bool(swoole_client_coro_class_entry_ptr, getThis(), ZEND_STRL("connected"), 1);
     RETURN_TRUE;
 }
 
@@ -744,16 +733,9 @@ static PHP_METHOD(swoole_client_coro, send)
     char *data;
     zend_size_t data_len;
 
-#ifdef FAST_ZPP
-    ZEND_PARSE_PARAMETERS_START(1, 2)
+    ZEND_PARSE_PARAMETERS_START(1, 1)
         Z_PARAM_STRING(data, data_len)
     ZEND_PARSE_PARAMETERS_END();
-#else
-    if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "s", &data, &data_len) == FAILURE)
-    {
-        return;
-    }
-#endif
 
     if (data_len <= 0)
     {
@@ -761,7 +743,7 @@ static PHP_METHOD(swoole_client_coro, send)
         RETURN_FALSE;
     }
 
-    Socket *cli = client_get_ptr(getThis() TSRMLS_CC);
+    Socket *cli = client_get_ptr(getThis());
     if (!cli)
     {
         RETURN_FALSE;
@@ -773,7 +755,7 @@ static PHP_METHOD(swoole_client_coro, send)
     if (ret < 0)
     {
         swoole_php_sys_error(E_WARNING, "failed to send(%d) %zd bytes.", cli->socket->fd, data_len);
-        zend_update_property_long(swoole_client_coro_class_entry_ptr, getThis(), SW_STRL("errCode")-1, SwooleG.error TSRMLS_CC);
+        zend_update_property_long(swoole_client_coro_class_entry_ptr, getThis(), ZEND_STRL("errCode"), SwooleG.error);
         RETVAL_FALSE;
     }
     else
@@ -790,7 +772,7 @@ static PHP_METHOD(swoole_client_coro, sendto)
     char *data;
     zend_size_t len;
 
-    if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "sls", &ip, &ip_len, &port, &data, &len) == FAILURE)
+    if (zend_parse_parameters(ZEND_NUM_ARGS(), "sls", &ip, &ip_len, &port, &data, &len) == FAILURE)
     {
         return;
     }
@@ -820,7 +802,7 @@ static PHP_METHOD(swoole_client_coro, recvfrom)
     zend_long length;
     zval *port, *address;
 
-    if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "lz/|z/", &length, &address, &port) == FAILURE)
+    if (zend_parse_parameters(ZEND_NUM_ARGS(), "lz/|z/", &length, &address, &port) == FAILURE)
     {
         return;
     }
@@ -867,7 +849,7 @@ static PHP_METHOD(swoole_client_coro, sendfile)
     long offset = 0;
     long length = 0;
 
-    if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "s|ll", &file, &file_len, &offset, &length) == FAILURE)
+    if (zend_parse_parameters(ZEND_NUM_ARGS(), "s|ll", &file, &file_len, &offset, &length) == FAILURE)
     {
         return;
     }
@@ -877,7 +859,7 @@ static PHP_METHOD(swoole_client_coro, sendfile)
         RETURN_FALSE;
     }
 
-    Socket *cli = client_get_ptr(getThis() TSRMLS_CC);
+    Socket *cli = client_get_ptr(getThis());
     if (!cli)
     {
         RETURN_FALSE;
@@ -895,7 +877,7 @@ static PHP_METHOD(swoole_client_coro, sendfile)
     {
         SwooleG.error = errno;
         swoole_php_fatal_error(E_WARNING, "sendfile() failed. Error: %s [%d]", strerror(SwooleG.error), SwooleG.error);
-        zend_update_property_long(swoole_client_coro_class_entry_ptr, getThis(), SW_STRL("errCode")-1, SwooleG.error TSRMLS_CC);
+        zend_update_property_long(swoole_client_coro_class_entry_ptr, getThis(), ZEND_STRL("errCode"), SwooleG.error);
         RETVAL_FALSE;
     }
     else
@@ -908,20 +890,12 @@ static PHP_METHOD(swoole_client_coro, recv)
 {
     double timeout = 0;
 
-#ifdef FAST_ZPP
-    ZEND_PARSE_PARAMETERS_START(0, 2)
+    ZEND_PARSE_PARAMETERS_START(0, 1)
         Z_PARAM_OPTIONAL
-        Z_PARAM_LONG(buf_len)
-        Z_PARAM_LONG(flags)
+        Z_PARAM_DOUBLE(timeout)
     ZEND_PARSE_PARAMETERS_END();
-#else
-    if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "|d", &timeout) == FAILURE)
-    {
-        return;
-    }
-#endif
 
-    Socket *cli = client_get_ptr(getThis() TSRMLS_CC);
+    Socket *cli = client_get_ptr(getThis());
     if (!cli)
     {
         RETURN_FALSE;
@@ -958,7 +932,7 @@ static PHP_METHOD(swoole_client_coro, recv)
     {
         SwooleG.error = cli->errCode;
         swoole_php_error(E_WARNING, "recv() failed. Error: %s [%d]", strerror(SwooleG.error), SwooleG.error);
-        zend_update_property_long(swoole_client_coro_class_entry_ptr, getThis(), SW_STRL("errCode")-1, SwooleG.error TSRMLS_CC);
+        zend_update_property_long(swoole_client_coro_class_entry_ptr, getThis(), ZEND_STRL("errCode"), SwooleG.error);
         RETURN_FALSE;
     }
     else if (retval == 0)
@@ -973,19 +947,12 @@ static PHP_METHOD(swoole_client_coro, peek)
     int ret;
     char *buf = NULL;
 
-#ifdef FAST_ZPP
     ZEND_PARSE_PARAMETERS_START(0, 1)
         Z_PARAM_OPTIONAL
         Z_PARAM_LONG(buf_len)
     ZEND_PARSE_PARAMETERS_END();
-#else
-    if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "|l", &buf_len) == FAILURE)
-    {
-        return;
-    }
-#endif
 
-    Socket *cli = client_get_ptr(getThis() TSRMLS_CC);
+    Socket *cli = client_get_ptr(getThis());
     if (!cli)
     {
         RETURN_FALSE;
@@ -999,15 +966,16 @@ static PHP_METHOD(swoole_client_coro, peek)
     {
         SwooleG.error = errno;
         swoole_php_error(E_WARNING, "recv() failed. Error: %s [%d]", strerror(SwooleG.error), SwooleG.error);
-        zend_update_property_long(swoole_client_coro_class_entry_ptr, getThis(), SW_STRL("errCode")-1,
-                SwooleG.error TSRMLS_CC);
+        zend_update_property_long(swoole_client_coro_class_entry_ptr, getThis(), ZEND_STRL("errCode"),
+                SwooleG.error);
         swoole_efree(buf);
         RETURN_FALSE;
     }
     else
     {
         buf[ret] = 0;
-        SW_RETVAL_STRINGL(buf, ret, 0);
+        RETVAL_STRINGL(buf, ret);
+        efree(buf);
     }
 }
 
@@ -1026,7 +994,7 @@ static PHP_METHOD(swoole_client_coro, isConnected)
 
 static PHP_METHOD(swoole_client_coro, getsockname)
 {
-    Socket *cli = client_get_ptr(getThis() TSRMLS_CC);
+    Socket *cli = client_get_ptr(getThis());
     if (!cli)
     {
         RETURN_FALSE;
@@ -1052,7 +1020,7 @@ static PHP_METHOD(swoole_client_coro, getsockname)
         char tmp[INET6_ADDRSTRLEN];
         if (inet_ntop(AF_INET6, &cli->socket->info.addr.inet_v6.sin6_addr, tmp, sizeof(tmp)))
         {
-            sw_add_assoc_string(return_value, "host", tmp, 1);
+            add_assoc_string(return_value, "host", tmp);
         }
         else
         {
@@ -1062,7 +1030,7 @@ static PHP_METHOD(swoole_client_coro, getsockname)
     else
     {
         add_assoc_long(return_value, "port", ntohs(cli->socket->info.addr.inet_v4.sin_port));
-        sw_add_assoc_string(return_value, "host", inet_ntoa(cli->socket->info.addr.inet_v4.sin_addr), 1);
+        add_assoc_string(return_value, "host", inet_ntoa(cli->socket->info.addr.inet_v4.sin_addr));
     }
 }
 
@@ -1074,7 +1042,7 @@ static PHP_METHOD(swoole_client_coro, getSocket)
     {
         RETURN_ZVAL(zsocket, 1, NULL);
     }
-    Socket *cli = client_get_ptr(getThis() TSRMLS_CC);
+    Socket *cli = client_get_ptr(getThis());
     if (!cli)
     {
         RETURN_FALSE;
@@ -1086,14 +1054,14 @@ static PHP_METHOD(swoole_client_coro, getSocket)
     }
     SW_ZEND_REGISTER_RESOURCE(return_value, (void * ) socket_object, php_sockets_le_socket());
     zsocket = sw_zval_dup(return_value);
-    sw_zval_add_ref(&zsocket);
+    Z_TRY_ADDREF_P(zsocket);
     swoole_set_property(getThis(), client_property_socket, zsocket);
 }
 #endif
 
 static PHP_METHOD(swoole_client_coro, getpeername)
 {
-    Socket *cli = client_get_ptr(getThis() TSRMLS_CC);
+    Socket *cli = client_get_ptr(getThis());
     if (!cli)
     {
         RETURN_FALSE;
@@ -1103,7 +1071,7 @@ static PHP_METHOD(swoole_client_coro, getpeername)
     {
         array_init(return_value);
         add_assoc_long(return_value, "port", ntohs(cli->socket->info.addr.inet_v4.sin_port));
-        sw_add_assoc_string(return_value, "host", inet_ntoa(cli->socket->info.addr.inet_v4.sin_addr), 1);
+        add_assoc_string(return_value, "host", inet_ntoa(cli->socket->info.addr.inet_v4.sin_addr));
     }
     else if (cli->type == SW_SOCK_UDP6)
     {
@@ -1113,7 +1081,7 @@ static PHP_METHOD(swoole_client_coro, getpeername)
 
         if (inet_ntop(AF_INET6, &cli->socket->info.addr.inet_v6.sin6_addr, tmp, sizeof(tmp)))
         {
-            sw_add_assoc_string(return_value, "host", tmp, 1);
+            add_assoc_string(return_value, "host", tmp);
         }
         else
         {
@@ -1137,14 +1105,14 @@ static PHP_METHOD(swoole_client_coro, close)
         RETURN_FALSE;
     }
     ret = cli->close();
-    php_swoole_client_coro_free(getThis(), cli TSRMLS_CC);
+    php_swoole_client_coro_free(getThis(), cli);
     SW_CHECK_RETURN(ret);
 }
 
 #ifdef SW_USE_OPENSSL
 static PHP_METHOD(swoole_client_coro, enableSSL)
 {
-    Socket *cli = client_get_ptr(getThis() TSRMLS_CC);
+    Socket *cli = client_get_ptr(getThis());
     if (!cli)
     {
         RETURN_FALSE;
@@ -1160,10 +1128,10 @@ static PHP_METHOD(swoole_client_coro, enableSSL)
         RETURN_FALSE;
     }
     cli->open_ssl = true;
-    zval *zset = sw_zend_read_property(swoole_client_coro_class_entry_ptr, getThis(), ZEND_STRL("setting"), 1 TSRMLS_CC);
+    zval *zset = sw_zend_read_property(swoole_client_coro_class_entry_ptr, getThis(), ZEND_STRL("setting"), 1);
     if (zset && !ZVAL_IS_NULL(zset))
     {
-        client_coro_check_ssl_setting(cli, zset TSRMLS_CC);
+        client_coro_check_ssl_setting(cli, zset);
     }
     if (cli->ssl_handshake() == false)
     {
@@ -1174,7 +1142,7 @@ static PHP_METHOD(swoole_client_coro, enableSSL)
 
 static PHP_METHOD(swoole_client_coro, getPeerCert)
 {
-    Socket *cli = client_get_ptr(getThis() TSRMLS_CC);
+    Socket *cli = client_get_ptr(getThis());
     if (!cli)
     {
         RETURN_FALSE;
@@ -1190,12 +1158,12 @@ static PHP_METHOD(swoole_client_coro, getPeerCert)
     {
         RETURN_FALSE;
     }
-    SW_RETURN_STRINGL(buf, n, 1);
+    RETURN_STRINGL(buf, n);
 }
 
 static PHP_METHOD(swoole_client_coro, verifyPeerCert)
 {
-    Socket *cli = client_get_ptr(getThis() TSRMLS_CC);
+    Socket *cli = client_get_ptr(getThis());
     if (!cli)
     {
         RETURN_FALSE;
@@ -1206,13 +1174,10 @@ static PHP_METHOD(swoole_client_coro, verifyPeerCert)
         RETURN_FALSE;
     }
     zend_bool allow_self_signed = 0;
-    if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "|b", &allow_self_signed) == FAILURE)
+    if (zend_parse_parameters(ZEND_NUM_ARGS(), "|b", &allow_self_signed) == FAILURE)
     {
         return;
     }
     SW_CHECK_RETURN(cli->ssl_verify(allow_self_signed));
 }
 #endif
-
-
-
