@@ -214,7 +214,7 @@
  * HTTP Protocol
  */
 #define SW_HTTP_SERVER_SOFTWARE          "swoole-http-server"
-#define SW_HTTP_BAD_REQUEST              "<h1>400 Bad Request</h1>\r\n"
+#define SW_HTTP_BAD_REQUEST_TIP          "<h1>400 Bad Request</h1>\r\n"
 #define SW_HTTP_PARAM_MAX_NUM            128
 #define SW_HTTP_COOKIE_KEYLEN            128
 #define SW_HTTP_COOKIE_VALLEN            4096
