@@ -51,17 +51,17 @@ static void free_event_callback(void* data)
     php_reactor_fd *ev_set = (php_reactor_fd*) data;
     if (ev_set->cb_read)
     {
-        sw_zval_ptr_dtor(&(ev_set->cb_read));
+        zval_ptr_dtor((ev_set->cb_read));
         ev_set->cb_read = NULL;
     }
     if (ev_set->cb_write)
     {
-        sw_zval_ptr_dtor(&(ev_set->cb_write));
+        zval_ptr_dtor((ev_set->cb_write));
         ev_set->cb_write = NULL;
     }
     if (ev_set->socket)
     {
-        sw_zval_ptr_dtor(&(ev_set->socket));
+        zval_ptr_dtor((ev_set->socket));
         ev_set->socket = NULL;
     }
     efree(ev_set);
@@ -70,20 +70,20 @@ static void free_event_callback(void* data)
 static void free_callback(void* data)
 {
     php_defer_callback *cb = (php_defer_callback *) data;
-    sw_zval_ptr_dtor(&cb->callback);
+    zval_ptr_dtor(cb->callback);
     efree(cb);
 }
 
 static int php_swoole_event_onRead(swReactor *reactor, swEvent *event)
 {
     zval *retval;
-    zval **args[1];
+    zval args[1];
     php_reactor_fd *fd = event->socket->object;
 
 
-    args[0] = &fd->socket;
+    args[0] = *fd->socket;
 
-    if (sw_call_user_function_ex(EG(function_table), NULL, fd->cb_read, &retval, 1, args, 0, NULL TSRMLS_CC) == FAILURE)
+    if (sw_call_user_function_ex(EG(function_table), NULL, fd->cb_read, &retval, 1, args, 0, NULL) == FAILURE)
     {
         swoole_php_fatal_error(E_WARNING, "swoole_event: onRead handler error.");
         SwooleG.main_reactor->del(SwooleG.main_reactor, event->fd);
@@ -91,11 +91,11 @@ static int php_swoole_event_onRead(swReactor *reactor, swEvent *event)
     }
     if (EG(exception))
     {
-        zend_exception_error(EG(exception), E_ERROR TSRMLS_CC);
+        zend_exception_error(EG(exception), E_ERROR);
     }
     if (retval != NULL)
     {
-        sw_zval_ptr_dtor(&retval);
+        zval_ptr_dtor(retval);
     }
     return SW_OK;
 }
@@ -103,7 +103,7 @@ static int php_swoole_event_onRead(swReactor *reactor, swEvent *event)
 static int php_swoole_event_onWrite(swReactor *reactor, swEvent *event)
 {
     zval *retval;
-    zval **args[1];
+    zval args[1];
     php_reactor_fd *fd = event->socket->object;
 
 
@@ -112,9 +112,9 @@ static int php_swoole_event_onWrite(swReactor *reactor, swEvent *event)
         return swReactor_onWrite(reactor, event);
     }
 
-    args[0] = &fd->socket;
+    args[0] = *fd->socket;
 
-    if (sw_call_user_function_ex(EG(function_table), NULL, fd->cb_write, &retval, 1, args, 0, NULL TSRMLS_CC) == FAILURE)
+    if (sw_call_user_function_ex(EG(function_table), NULL, fd->cb_write, &retval, 1, args, 0, NULL) == FAILURE)
     {
         swoole_php_fatal_error(E_WARNING, "swoole_event: onWrite handler error");
         SwooleG.main_reactor->del(SwooleG.main_reactor, event->fd);
@@ -122,11 +122,11 @@ static int php_swoole_event_onWrite(swReactor *reactor, swEvent *event)
     }
     if (EG(exception))
     {
-        zend_exception_error(EG(exception), E_ERROR TSRMLS_CC);
+        zend_exception_error(EG(exception), E_ERROR);
     }
     if (retval != NULL)
     {
-        sw_zval_ptr_dtor(&retval);
+        zval_ptr_dtor(retval);
     }
     return SW_OK;
 }
@@ -160,20 +160,20 @@ static void php_swoole_event_onDefer(void *_cb)
     php_defer_callback *defer = _cb;
 
     zval *retval;
-    if (sw_call_user_function_ex(EG(function_table), NULL, defer->callback, &retval, 0, NULL, 0, NULL TSRMLS_CC) == FAILURE)
+    if (sw_call_user_function_ex(EG(function_table), NULL, defer->callback, &retval, 0, NULL, 0, NULL) == FAILURE)
     {
         swoole_php_fatal_error(E_WARNING, "swoole_event: defer handler error");
         return;
     }
     if (EG(exception))
     {
-        zend_exception_error(EG(exception), E_ERROR TSRMLS_CC);
+        zend_exception_error(EG(exception), E_ERROR);
     }
     if (retval != NULL)
     {
-        sw_zval_ptr_dtor(&retval);
+        zval_ptr_dtor(retval);
     }
-    sw_zval_ptr_dtor(&defer->callback);
+    zval_ptr_dtor(defer->callback);
     efree(defer);
 }
 
@@ -182,40 +182,29 @@ static void php_swoole_event_onEndCallback(void *_cb)
     php_defer_callback *defer = _cb;
 
     zval *retval;
-    if (sw_call_user_function_ex(EG(function_table), NULL, defer->callback, &retval, 0, NULL, 0, NULL TSRMLS_CC) == FAILURE)
+    if (sw_call_user_function_ex(EG(function_table), NULL, defer->callback, &retval, 0, NULL, 0, NULL) == FAILURE)
     {
         swoole_php_fatal_error(E_WARNING, "swoole_event: defer handler error");
         return;
     }
     if (EG(exception))
     {
-        zend_exception_error(EG(exception), E_ERROR TSRMLS_CC);
+        zend_exception_error(EG(exception), E_ERROR);
     }
     if (retval != NULL)
     {
-        sw_zval_ptr_dtor(&retval);
+        zval_ptr_dtor(retval);
     }
 }
 
-void php_swoole_check_reactor()
+void php_swoole_reactor_init()
 {
-    if (likely(SwooleWG.reactor_init))
-    {
-        return;
-    }
-
     if (!SWOOLE_G(cli))
     {
         swoole_php_fatal_error(E_ERROR, "async-io must be used in PHP CLI mode.");
         return;
     }
 
-    if (swIsTaskWorker())
-    {
-        swoole_php_fatal_error(E_ERROR, "can't use async-io in task process.");
-        return;
-    }
-
     if (SwooleG.main_reactor == NULL)
     {
         swTraceLog(SW_TRACE_PHP, "init reactor");
@@ -281,16 +270,18 @@ void php_swoole_event_wait()
 #ifdef SW_COROUTINE
         if (COROG.active == 0)
         {
-            coro_init(TSRMLS_C);
+            coro_init();
         }
 #endif
         if (!swReactor_empty(SwooleG.main_reactor))
         {
+            SW_SAVE_EG_SCOPE(scope);
             int ret = SwooleG.main_reactor->wait(SwooleG.main_reactor, NULL);
             if (ret < 0)
             {
                 swoole_php_fatal_error(E_ERROR, "reactor wait failed. Error: %s [%d]", strerror(errno), errno);
             }
+            SW_RESUME_EG_SCOPE(scope);
         }
         if (SwooleG.timer.map)
         {
@@ -300,7 +291,19 @@ void php_swoole_event_wait()
     }
 }
 
-int swoole_convert_to_fd(zval *zfd TSRMLS_DC)
+void php_swoole_event_exit()
+{
+    if (SwooleWG.in_client == 1)
+    {
+        if (SwooleG.main_reactor)
+        {
+            SwooleG.main_reactor->running = 0;
+        }
+        SwooleG.running = 0;
+    }
+}
+
+int swoole_convert_to_fd(zval *zfd)
 {
     php_stream *stream;
     int socket_fd;
@@ -308,7 +311,7 @@ int swoole_convert_to_fd(zval *zfd TSRMLS_DC)
 #ifdef SWOOLE_SOCKETS_SUPPORT
     php_socket *php_sock;
 #endif
-    if (SW_Z_TYPE_P(zfd) == IS_RESOURCE)
+    if (Z_TYPE_P(zfd) == IS_RESOURCE)
     {
         if (SW_ZEND_FETCH_RESOURCE_NO_RETURN(stream, php_stream *, &zfd, -1, NULL, php_file_le_stream()))
         {
@@ -336,7 +339,7 @@ int swoole_convert_to_fd(zval *zfd TSRMLS_DC)
 #endif
         }
     }
-    else if (SW_Z_TYPE_P(zfd) == IS_LONG)
+    else if (Z_TYPE_P(zfd) == IS_LONG)
     {
         socket_fd = Z_LVAL_P(zfd);
         if (socket_fd < 0)
@@ -345,16 +348,16 @@ int swoole_convert_to_fd(zval *zfd TSRMLS_DC)
             return SW_ERR;
         }
     }
-    else if (SW_Z_TYPE_P(zfd) == IS_OBJECT)
+    else if (Z_TYPE_P(zfd) == IS_OBJECT)
     {
         zval *zsock = NULL;
-        if (instanceof_function(Z_OBJCE_P(zfd), swoole_client_class_entry_ptr TSRMLS_CC))
+        if (instanceof_function(Z_OBJCE_P(zfd), swoole_client_class_entry_ptr))
         {
-            zsock = sw_zend_read_property(Z_OBJCE_P(zfd), zfd, SW_STRL("sock")-1, 0 TSRMLS_CC);
+            zsock = sw_zend_read_property(Z_OBJCE_P(zfd), zfd, ZEND_STRL("sock"), 0);
         }
-        else if (instanceof_function(Z_OBJCE_P(zfd), swoole_process_class_entry_ptr TSRMLS_CC))
+        else if (instanceof_function(Z_OBJCE_P(zfd), swoole_process_class_entry_ptr))
         {
-            zsock = sw_zend_read_property(Z_OBJCE_P(zfd), zfd, SW_STRL("pipe")-1, 0 TSRMLS_CC);
+            zsock = sw_zend_read_property(Z_OBJCE_P(zfd), zfd, ZEND_STRL("pipe"), 0);
         }
         if (zsock == NULL || ZVAL_IS_NULL(zsock))
         {
@@ -370,7 +373,7 @@ int swoole_convert_to_fd(zval *zfd TSRMLS_DC)
     return socket_fd;
 }
 
-int swoole_convert_to_fd_ex(zval *zfd, int *async TSRMLS_DC)
+int swoole_convert_to_fd_ex(zval *zfd, int *async)
 {
     php_stream *stream;
     int fd;
@@ -379,7 +382,7 @@ int swoole_convert_to_fd_ex(zval *zfd, int *async TSRMLS_DC)
     php_socket *php_sock;
 #endif
 
-    if (SW_Z_TYPE_P(zfd) != IS_RESOURCE)
+    if (Z_TYPE_P(zfd) != IS_RESOURCE)
     {
         swoole_php_fatal_error(E_WARNING, "fd argument must be either valid PHP stream or valid PHP socket resource");
         return SW_ERR;
@@ -448,7 +451,7 @@ PHP_FUNCTION(swoole_event_add)
     char *func_name = NULL;
     long event_flag = 0;
 
-    if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "z|zzl", &zfd, &cb_read, &cb_write, &event_flag) == FAILURE)
+    if (zend_parse_parameters(ZEND_NUM_ARGS(), "z|zzl", &zfd, &cb_read, &cb_write, &event_flag) == FAILURE)
     {
         return;
     }
@@ -459,7 +462,7 @@ PHP_FUNCTION(swoole_event_add)
         RETURN_FALSE;
     }
 
-    int socket_fd = swoole_convert_to_fd(zfd TSRMLS_CC);
+    int socket_fd = swoole_convert_to_fd(zfd);
     if (socket_fd < 0)
     {
         swoole_php_fatal_error(E_WARNING, "unknow type.");
@@ -474,11 +477,11 @@ PHP_FUNCTION(swoole_event_add)
     php_reactor_fd *reactor_fd = emalloc(sizeof(php_reactor_fd));
     reactor_fd->socket = zfd;
     sw_copy_to_stack(reactor_fd->socket, reactor_fd->stack.socket);
-    sw_zval_add_ref(&reactor_fd->socket);
+    Z_TRY_ADDREF_P(reactor_fd->socket);
 
     if (cb_read!= NULL && !ZVAL_IS_NULL(cb_read))
     {
-        if (!sw_zend_is_callable(cb_read, 0, &func_name TSRMLS_CC))
+        if (!sw_zend_is_callable(cb_read, 0, &func_name))
         {
             swoole_php_fatal_error(E_ERROR, "Function '%s' is not callable", func_name);
             efree(func_name);
@@ -486,7 +489,7 @@ PHP_FUNCTION(swoole_event_add)
         }
         efree(func_name);
         reactor_fd->cb_read = cb_read;
-        sw_zval_add_ref(&cb_read);
+        Z_TRY_ADDREF_P(cb_read);
         sw_copy_to_stack(reactor_fd->cb_read, reactor_fd->stack.cb_read);
     }
     else
@@ -496,7 +499,7 @@ PHP_FUNCTION(swoole_event_add)
 
     if (cb_write!= NULL && !ZVAL_IS_NULL(cb_write))
     {
-        if (!sw_zend_is_callable(cb_write, 0, &func_name TSRMLS_CC))
+        if (!sw_zend_is_callable(cb_write, 0, &func_name))
         {
             swoole_php_fatal_error(E_ERROR, "Function '%s' is not callable", func_name);
             efree(func_name);
@@ -504,7 +507,7 @@ PHP_FUNCTION(swoole_event_add)
         }
         efree(func_name);
         reactor_fd->cb_write = cb_write;
-        sw_zval_add_ref(&cb_write);
+        Z_TRY_ADDREF_P(cb_write);
         sw_copy_to_stack(reactor_fd->cb_write, reactor_fd->stack.cb_write);
     }
     else
@@ -535,7 +538,7 @@ PHP_FUNCTION(swoole_event_write)
     char *data;
     zend_size_t len;
 
-    if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "zs", &zfd, &data, &len) == FAILURE)
+    if (zend_parse_parameters(ZEND_NUM_ARGS(), "zs", &zfd, &data, &len) == FAILURE)
     {
         return;
     }
@@ -546,7 +549,7 @@ PHP_FUNCTION(swoole_event_write)
         RETURN_FALSE;
     }
 
-    int socket_fd = swoole_convert_to_fd(zfd TSRMLS_CC);
+    int socket_fd = swoole_convert_to_fd(zfd);
     if (socket_fd < 0)
     {
         swoole_php_fatal_error(E_WARNING, "unknow type.");
@@ -578,12 +581,12 @@ PHP_FUNCTION(swoole_event_set)
         RETURN_FALSE;
     }
 
-    if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "z|zzl", &zfd, &cb_read, &cb_write, &event_flag) == FAILURE)
+    if (zend_parse_parameters(ZEND_NUM_ARGS(), "z|zzl", &zfd, &cb_read, &cb_write, &event_flag) == FAILURE)
     {
         return;
     }
 
-    int socket_fd = swoole_convert_to_fd(zfd TSRMLS_CC);
+    int socket_fd = swoole_convert_to_fd(zfd);
     if (socket_fd < 0)
     {
         swoole_php_fatal_error(E_WARNING, "unknow type.");
@@ -601,7 +604,7 @@ PHP_FUNCTION(swoole_event_set)
     php_reactor_fd *ev_set = socket->object;
     if (cb_read != NULL && !ZVAL_IS_NULL(cb_read))
     {
-        if (!sw_zend_is_callable(cb_read, 0, &func_name TSRMLS_CC))
+        if (!sw_zend_is_callable(cb_read, 0, &func_name))
         {
             swoole_php_fatal_error(E_ERROR, "Function '%s' is not callable", func_name);
             efree(func_name);
@@ -611,10 +614,10 @@ PHP_FUNCTION(swoole_event_set)
         {
             if (ev_set->cb_read)
             {
-                sw_zval_ptr_dtor(&ev_set->cb_read);
+                zval_ptr_dtor(ev_set->cb_read);
             }
             ev_set->cb_read = cb_read;
-            sw_zval_add_ref(&cb_read);
+            Z_TRY_ADDREF_P(cb_read);
             sw_copy_to_stack(ev_set->cb_read, ev_set->stack.cb_read);
             efree(func_name);
         }
@@ -627,7 +630,7 @@ PHP_FUNCTION(swoole_event_set)
             swoole_php_fatal_error(E_WARNING, "invalid socket fd [%d].", socket_fd);
             RETURN_FALSE;
         }
-        if (!sw_zend_is_callable(cb_write, 0, &func_name TSRMLS_CC))
+        if (!sw_zend_is_callable(cb_write, 0, &func_name))
         {
             swoole_php_fatal_error(E_ERROR, "Function '%s' is not callable", func_name);
             efree(func_name);
@@ -637,10 +640,10 @@ PHP_FUNCTION(swoole_event_set)
         {
             if (ev_set->cb_write)
             {
-                sw_zval_ptr_dtor(&ev_set->cb_write);
+                zval_ptr_dtor(ev_set->cb_write);
             }
             ev_set->cb_write = cb_write;
-            sw_zval_add_ref(&cb_write);
+            Z_TRY_ADDREF_P(cb_write);
             sw_copy_to_stack(ev_set->cb_write, ev_set->stack.cb_write);
             efree(func_name);
         }
@@ -677,12 +680,12 @@ PHP_FUNCTION(swoole_event_del)
         RETURN_FALSE;
     }
 
-    if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "z", &zfd) == FAILURE)
+    if (zend_parse_parameters(ZEND_NUM_ARGS(), "z", &zfd) == FAILURE)
     {
         return;
     }
 
-    int socket_fd = swoole_convert_to_fd(zfd TSRMLS_CC);
+    int socket_fd = swoole_convert_to_fd(zfd);
     if (socket_fd < 0)
     {
         swoole_php_fatal_error(E_WARNING, "unknow type.");
@@ -704,13 +707,13 @@ PHP_FUNCTION(swoole_event_del)
 PHP_FUNCTION(swoole_event_defer)
 {
     zval *callback;
-    if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "z", &callback) == FAILURE)
+    if (zend_parse_parameters(ZEND_NUM_ARGS(), "z", &callback) == FAILURE)
     {
         return;
     }
 
     char *func_name;
-    if (!sw_zend_is_callable(callback, 0, &func_name TSRMLS_CC))
+    if (!sw_zend_is_callable(callback, 0, &func_name))
     {
         swoole_php_fatal_error(E_ERROR, "Function '%s' is not callable", func_name);
         efree(func_name);
@@ -723,7 +726,7 @@ PHP_FUNCTION(swoole_event_defer)
     php_defer_callback *defer = emalloc(sizeof(php_defer_callback));
     defer->callback = &defer->_callback;
     memcpy(defer->callback, callback, sizeof(zval));
-    sw_zval_add_ref(&callback);
+    Z_TRY_ADDREF_P(callback);
     SW_CHECK_RETURN(SwooleG.main_reactor->defer(SwooleG.main_reactor, php_swoole_event_onDefer, defer));
 }
 
@@ -738,7 +741,7 @@ PHP_FUNCTION(swoole_event_cycle)
     zval *callback;
     zend_bool before = 0;
 
-    if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "z|b", &callback, &before) == FAILURE)
+    if (zend_parse_parameters(ZEND_NUM_ARGS(), "z|b", &callback, &before) == FAILURE)
     {
         return;
     }
@@ -759,7 +762,7 @@ PHP_FUNCTION(swoole_event_cycle)
     }
 
     char *func_name;
-    if (!sw_zend_is_callable(callback, 0, &func_name TSRMLS_CC))
+    if (!sw_zend_is_callable(callback, 0, &func_name))
     {
         swoole_php_fatal_error(E_ERROR, "Function '%s' is not callable", func_name);
         efree(func_name);
@@ -771,7 +774,7 @@ PHP_FUNCTION(swoole_event_cycle)
 
     cb->callback = &cb->_callback;
     memcpy(cb->callback, callback, sizeof(zval));
-    sw_zval_add_ref(&callback);
+    Z_TRY_ADDREF_P(callback);
 
     if (before == 0)
     {
@@ -801,14 +804,7 @@ PHP_FUNCTION(swoole_event_cycle)
 
 PHP_FUNCTION(swoole_event_exit)
 {
-    if (SwooleWG.in_client == 1)
-    {
-        if (SwooleG.main_reactor)
-        {
-            SwooleG.main_reactor->running = 0;
-        }
-        SwooleG.running = 0;
-    }
+    php_swoole_event_exit();
 }
 
 PHP_FUNCTION(swoole_event_wait)
@@ -838,7 +834,7 @@ PHP_FUNCTION(swoole_event_dispatch)
 #ifdef SW_COROUTINE
     if (COROG.active == 0)
     {
-        coro_init(TSRMLS_C);
+        coro_init();
     }
 #endif
 
@@ -862,12 +858,12 @@ PHP_FUNCTION(swoole_event_isset)
     zval *zfd;
     long events = SW_EVENT_READ | SW_EVENT_WRITE;
 
-    if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "z|l", &zfd, &events) == FAILURE)
+    if (zend_parse_parameters(ZEND_NUM_ARGS(), "z|l", &zfd, &events) == FAILURE)
     {
         return;
     }
 
-    int socket_fd = swoole_convert_to_fd(zfd TSRMLS_CC);
+    int socket_fd = swoole_convert_to_fd(zfd);
     if (socket_fd < 0)
     {
         swoole_php_fatal_error(E_WARNING, "unknow type.");
