@@ -95,7 +95,7 @@ static int swoole_redis_onRead(swReactor *reactor, swEvent *event);
 static int swoole_redis_onWrite(swReactor *reactor, swEvent *event);
 static int swoole_redis_onError(swReactor *reactor, swEvent *event);
 static void swoole_redis_onResult(redisAsyncContext *c, void *r, void *privdata);
-static void swoole_redis_parse_result(swRedisClient *redis, zval* return_value, redisReply* reply TSRMLS_DC);
+static void swoole_redis_parse_result(swRedisClient *redis, zval* return_value, redisReply* reply);
 static void swoole_redis_onCompleted(redisAsyncContext *c, void *r, void *privdata);
 static void swoole_redis_onTimeout(swTimer *timer, swTimer_node *tnode);
 
@@ -110,8 +110,8 @@ static zend_class_entry *swoole_redis_class_entry_ptr;
 
 static const zend_function_entry swoole_redis_methods[] =
 {
-    PHP_ME(swoole_redis, __construct, arginfo_swoole_redis_construct, ZEND_ACC_PUBLIC | ZEND_ACC_CTOR)
-    PHP_ME(swoole_redis, __destruct, arginfo_swoole_void, ZEND_ACC_PUBLIC | ZEND_ACC_DTOR)
+    PHP_ME(swoole_redis, __construct, arginfo_swoole_redis_construct, ZEND_ACC_PUBLIC)
+    PHP_ME(swoole_redis, __destruct, arginfo_swoole_void, ZEND_ACC_PUBLIC)
     PHP_ME(swoole_redis, on, arginfo_swoole_redis_on, ZEND_ACC_PUBLIC)
     PHP_ME(swoole_redis, connect, arginfo_swoole_redis_connect, ZEND_ACC_PUBLIC)
     PHP_ME(swoole_redis, close, arginfo_swoole_void, ZEND_ACC_PUBLIC)
@@ -144,61 +144,61 @@ static sw_inline int swoole_redis_is_message_command(char *command, int command_
     }
 }
 
-static sw_inline void redis_execute_connect_callback(swRedisClient *redis, int success TSRMLS_DC)
+static sw_inline void redis_execute_connect_callback(swRedisClient *redis, int success)
 {
     zval *result, *retval;
     SW_MAKE_STD_ZVAL(result);
     ZVAL_BOOL(result, success);
 
-    zval **args[2];
-    zval *zcallback = sw_zend_read_property(swoole_redis_class_entry_ptr, redis->object, ZEND_STRL("onConnect"), 0 TSRMLS_CC);
-    args[0] = &redis->object;
-    args[1] = &result;
+    zval args[2];
+    zval *zcallback = sw_zend_read_property(swoole_redis_class_entry_ptr, redis->object, ZEND_STRL("onConnect"), 0);
+    args[0] = *redis->object;
+    args[1] = *result;
     redis->connecting = 1;
-    if (sw_call_user_function_ex(EG(function_table), NULL, zcallback, &retval, 2, args, 0, NULL TSRMLS_CC) != SUCCESS)
+    if (sw_call_user_function_ex(EG(function_table), NULL, zcallback, &retval, 2, args, 0, NULL) != SUCCESS)
     {
         swoole_php_fatal_error(E_WARNING, "swoole_async_redis connect_callback handler error.");
     }
     if (EG(exception))
     {
-        zend_exception_error(EG(exception), E_ERROR TSRMLS_CC);
+        zend_exception_error(EG(exception), E_ERROR);
     }
     if (retval != NULL)
     {
-        sw_zval_ptr_dtor(&retval);
+        zval_ptr_dtor(retval);
     }
-    sw_zval_ptr_dtor(&result);
+    zval_ptr_dtor(result);
     redis->connecting = 0;
 }
 
-void swoole_redis_init(int module_number TSRMLS_DC)
+void swoole_redis_init(int module_number)
 {
     SWOOLE_INIT_CLASS_ENTRY(swoole_redis_ce, "swoole_redis", "Swoole\\Redis", swoole_redis_methods);
-    swoole_redis_class_entry_ptr = zend_register_internal_class(&swoole_redis_ce TSRMLS_CC);
+    swoole_redis_class_entry_ptr = zend_register_internal_class(&swoole_redis_ce);
     SWOOLE_CLASS_ALIAS(swoole_redis, "Swoole\\Redis");
 
-    zend_declare_property_null(swoole_redis_class_entry_ptr, ZEND_STRL("onConnect"), ZEND_ACC_PUBLIC TSRMLS_CC);
-    zend_declare_property_null(swoole_redis_class_entry_ptr, ZEND_STRL("onClose"), ZEND_ACC_PUBLIC TSRMLS_CC);
-    zend_declare_property_null(swoole_redis_class_entry_ptr, ZEND_STRL("onMessage"), ZEND_ACC_PUBLIC TSRMLS_CC);
+    zend_declare_property_null(swoole_redis_class_entry_ptr, ZEND_STRL("onConnect"), ZEND_ACC_PUBLIC);
+    zend_declare_property_null(swoole_redis_class_entry_ptr, ZEND_STRL("onClose"), ZEND_ACC_PUBLIC);
+    zend_declare_property_null(swoole_redis_class_entry_ptr, ZEND_STRL("onMessage"), ZEND_ACC_PUBLIC);
 
-    zend_declare_property_null(swoole_redis_class_entry_ptr, ZEND_STRL("setting"), ZEND_ACC_PUBLIC TSRMLS_CC);
-    zend_declare_property_null(swoole_redis_class_entry_ptr, ZEND_STRL("host"), ZEND_ACC_PUBLIC TSRMLS_CC);
-    zend_declare_property_null(swoole_redis_class_entry_ptr, ZEND_STRL("port"), ZEND_ACC_PUBLIC TSRMLS_CC);
-    zend_declare_property_null(swoole_redis_class_entry_ptr, ZEND_STRL("sock"), ZEND_ACC_PUBLIC TSRMLS_CC);
-    zend_declare_property_null(swoole_redis_class_entry_ptr, ZEND_STRL("errCode"), ZEND_ACC_PUBLIC TSRMLS_CC);
-    zend_declare_property_null(swoole_redis_class_entry_ptr, ZEND_STRL("errMsg"), ZEND_ACC_PUBLIC TSRMLS_CC);
+    zend_declare_property_null(swoole_redis_class_entry_ptr, ZEND_STRL("setting"), ZEND_ACC_PUBLIC);
+    zend_declare_property_null(swoole_redis_class_entry_ptr, ZEND_STRL("host"), ZEND_ACC_PUBLIC);
+    zend_declare_property_null(swoole_redis_class_entry_ptr, ZEND_STRL("port"), ZEND_ACC_PUBLIC);
+    zend_declare_property_null(swoole_redis_class_entry_ptr, ZEND_STRL("sock"), ZEND_ACC_PUBLIC);
+    zend_declare_property_null(swoole_redis_class_entry_ptr, ZEND_STRL("errCode"), ZEND_ACC_PUBLIC);
+    zend_declare_property_null(swoole_redis_class_entry_ptr, ZEND_STRL("errMsg"), ZEND_ACC_PUBLIC);
 
-    zend_declare_class_constant_long(swoole_redis_class_entry_ptr, SW_STRL("STATE_CONNECT")-1, SWOOLE_REDIS_STATE_CONNECT TSRMLS_CC);
-    zend_declare_class_constant_long(swoole_redis_class_entry_ptr, SW_STRL("STATE_READY")-1, SWOOLE_REDIS_STATE_READY TSRMLS_CC);
-    zend_declare_class_constant_long(swoole_redis_class_entry_ptr, SW_STRL("STATE_WAIT_RESULT")-1, SWOOLE_REDIS_STATE_WAIT_RESULT TSRMLS_CC);
-    zend_declare_class_constant_long(swoole_redis_class_entry_ptr, SW_STRL("STATE_SUBSCRIBE")-1, SWOOLE_REDIS_STATE_SUBSCRIBE TSRMLS_CC);
-    zend_declare_class_constant_long(swoole_redis_class_entry_ptr, SW_STRL("STATE_CLOSED")-1, SWOOLE_REDIS_STATE_CLOSED TSRMLS_CC);
+    zend_declare_class_constant_long(swoole_redis_class_entry_ptr, ZEND_STRL("STATE_CONNECT"), SWOOLE_REDIS_STATE_CONNECT);
+    zend_declare_class_constant_long(swoole_redis_class_entry_ptr, ZEND_STRL("STATE_READY"), SWOOLE_REDIS_STATE_READY);
+    zend_declare_class_constant_long(swoole_redis_class_entry_ptr, ZEND_STRL("STATE_WAIT_RESULT"), SWOOLE_REDIS_STATE_WAIT_RESULT);
+    zend_declare_class_constant_long(swoole_redis_class_entry_ptr, ZEND_STRL("STATE_SUBSCRIBE"), SWOOLE_REDIS_STATE_SUBSCRIBE);
+    zend_declare_class_constant_long(swoole_redis_class_entry_ptr, ZEND_STRL("STATE_CLOSED"), SWOOLE_REDIS_STATE_CLOSED);
 }
 
 static PHP_METHOD(swoole_redis, __construct)
 {
     zval *zset = NULL;
-    if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "|z", &zset) == FAILURE)
+    if (zend_parse_parameters(ZEND_NUM_ARGS(), "|z", &zset) == FAILURE)
     {
         return;
     }
@@ -213,8 +213,8 @@ static PHP_METHOD(swoole_redis, __construct)
     if (zset && !ZVAL_IS_NULL(zset))
     {
         php_swoole_array_separate(zset);
-        zend_update_property(swoole_redis_class_entry_ptr, getThis(), ZEND_STRL("setting"), zset TSRMLS_CC);
-        sw_zval_ptr_dtor(&zset);
+        zend_update_property(swoole_redis_class_entry_ptr, getThis(), ZEND_STRL("setting"), zset);
+        zval_ptr_dtor(zset);
 
         HashTable *vht;
         zval *ztmp;
@@ -270,7 +270,7 @@ static PHP_METHOD(swoole_redis, on)
     zend_size_t len;
     zval *cb;
 
-    if (zend_parse_parameters(ZEND_NUM_ARGS()TSRMLS_CC, "sz", &name, &len, &cb) == FAILURE)
+    if (zend_parse_parameters(ZEND_NUM_ARGS(), "sz", &name, &len, &cb) == FAILURE)
     {
         return;
     }
@@ -284,12 +284,12 @@ static PHP_METHOD(swoole_redis, on)
 
     if (strncasecmp("close", name, len) == 0)
     {
-        zend_update_property(swoole_redis_class_entry_ptr, getThis(), ZEND_STRL("onClose"), cb TSRMLS_CC);
+        zend_update_property(swoole_redis_class_entry_ptr, getThis(), ZEND_STRL("onClose"), cb);
     }
     else if (strncasecmp("message", name, len) == 0)
     {
-        zend_update_property(swoole_redis_class_entry_ptr, getThis(), ZEND_STRL("onMessage"), cb TSRMLS_CC);
-        redis->message_callback = sw_zend_read_property(swoole_redis_class_entry_ptr, getThis(), ZEND_STRL("onMessage"), 0 TSRMLS_CC);
+        zend_update_property(swoole_redis_class_entry_ptr, getThis(), ZEND_STRL("onMessage"), cb);
+        redis->message_callback = sw_zend_read_property(swoole_redis_class_entry_ptr, getThis(), ZEND_STRL("onMessage"), 0);
         sw_copy_to_stack(redis->message_callback, redis->_message_callback);
 
         redis->subscribe = 1;
@@ -309,7 +309,7 @@ static PHP_METHOD(swoole_redis, connect)
     long port;
     zval *callback;
 
-    if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "slz", &host, &host_len, &port, &callback) == FAILURE)
+    if (zend_parse_parameters(ZEND_NUM_ARGS(), "slz", &host, &host_len, &port, &callback) == FAILURE)
     {
         RETURN_FALSE;
     }
@@ -354,8 +354,8 @@ static PHP_METHOD(swoole_redis, connect)
     redisAsyncSetConnectCallback(context, swoole_redis_onConnect);
     redisAsyncSetDisconnectCallback(context, swoole_redis_onClose);
 
-    zend_update_property_long(swoole_redis_class_entry_ptr, getThis(), ZEND_STRL("sock"), context->c.fd TSRMLS_CC);
-    zend_update_property(swoole_redis_class_entry_ptr, getThis(), ZEND_STRL("onConnect"), callback TSRMLS_CC);
+    zend_update_property_long(swoole_redis_class_entry_ptr, getThis(), ZEND_STRL("sock"), context->c.fd);
+    zend_update_property(swoole_redis_class_entry_ptr, getThis(), ZEND_STRL("onConnect"), callback);
 
     redis->context = context;
     context->ev.addRead = swoole_redis_event_AddRead;
@@ -365,8 +365,8 @@ static PHP_METHOD(swoole_redis, connect)
     context->ev.cleanup = swoole_redis_event_Cleanup;
     context->ev.data = redis;
 
-    zend_update_property_string(swoole_redis_class_entry_ptr, getThis(), ZEND_STRL("host"), host TSRMLS_CC);
-    zend_update_property_long(swoole_redis_class_entry_ptr, getThis(), ZEND_STRL("port"), port TSRMLS_CC);
+    zend_update_property_string(swoole_redis_class_entry_ptr, getThis(), ZEND_STRL("host"), host);
+    zend_update_property_long(swoole_redis_class_entry_ptr, getThis(), ZEND_STRL("port"), port);
 
     if (SwooleG.main_reactor->add(SwooleG.main_reactor, redis->context->c.fd, PHP_SWOOLE_FD_REDIS | SW_EVENT_WRITE) < 0)
     {
@@ -376,11 +376,10 @@ static PHP_METHOD(swoole_redis, connect)
 
     if (redis->timeout > 0)
     {
-        php_swoole_check_timer((int) (redis->timeout * 1000));
-        redis->timer = SwooleG.timer.add(&SwooleG.timer, (int) (redis->timeout * 1000), 0, redis, swoole_redis_onTimeout);
+        redis->timer = swTimer_add(&SwooleG.timer, (int) (redis->timeout * 1000), 0, redis, swoole_redis_onTimeout);
     }
 
-    sw_zval_add_ref(&redis->object);
+    Z_TRY_ADDREF_P(redis->object);
 
     swConnection *conn = swReactor_get(SwooleG.main_reactor, redis->context->c.fd);
     conn->object = redis;
@@ -389,13 +388,16 @@ static PHP_METHOD(swoole_redis, connect)
 static void redis_close(void* data)
 {
     swRedisClient *redis = data;
-    redisAsyncDisconnect(redis->context);
+    if (redis->context)
+    {
+        redisAsyncDisconnect(redis->context);
+    }
 }
 
 static void redis_free_object(void *data)
 {
     zval *object = (zval*) data;
-    sw_zval_ptr_dtor(&object);
+    zval_ptr_dtor(object);
 }
 
 static PHP_METHOD(swoole_redis, close)
@@ -440,7 +442,7 @@ static PHP_METHOD(swoole_redis, __call)
     char *command;
     zend_size_t command_len;
 
-    if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "sz", &command, &command_len, &params) == FAILURE)
+    if (zend_parse_parameters(ZEND_NUM_ARGS(), "sz", &command, &command_len, &params) == FAILURE)
     {
         return;
     }
@@ -576,7 +578,7 @@ static PHP_METHOD(swoole_redis, __call)
             RETURN_FALSE;
         }
 
-        sw_zval_add_ref(&callback);
+        Z_TRY_ADDREF_P(callback);
         callback = sw_zval_dup(callback);
 
         SW_HASHTABLE_FOREACH_START(Z_ARRVAL_P(params), value)
@@ -614,19 +616,19 @@ static PHP_METHOD(swoole_redis, getState)
     RETURN_LONG(redis->state);
 }
 
-static void swoole_redis_set_error(swRedisClient *redis, zval* return_value, redisReply* reply TSRMLS_DC)
+static void swoole_redis_set_error(swRedisClient *redis, zval* return_value, redisReply* reply)
 {
     char *str = malloc(reply->len + 1);
     memcpy(str, reply->str, reply->len);
     str[reply->len] = 0;
 
     ZVAL_FALSE(return_value);
-    zend_update_property_long(swoole_redis_class_entry_ptr, redis->object, ZEND_STRL("errCode"), -1 TSRMLS_CC);
-    zend_update_property_string(swoole_redis_class_entry_ptr, redis->object, ZEND_STRL("errMsg"), str TSRMLS_CC);
+    zend_update_property_long(swoole_redis_class_entry_ptr, redis->object, ZEND_STRL("errCode"), -1);
+    zend_update_property_string(swoole_redis_class_entry_ptr, redis->object, ZEND_STRL("errMsg"), str);
     free(str);
 }
 
-static void swoole_redis_parse_result(swRedisClient *redis, zval* return_value, redisReply* reply TSRMLS_DC)
+static void swoole_redis_parse_result(swRedisClient *redis, zval* return_value, redisReply* reply)
 {
     zval *val;
     int j;
@@ -642,7 +644,7 @@ static void swoole_redis_parse_result(swRedisClient *redis, zval* return_value,
         break;
 
     case REDIS_REPLY_ERROR:
-        swoole_redis_set_error(redis, return_value, reply TSRMLS_CC);
+        swoole_redis_set_error(redis, return_value, reply);
         break;
 
     case REDIS_REPLY_STATUS:
@@ -650,7 +652,7 @@ static void swoole_redis_parse_result(swRedisClient *redis, zval* return_value,
         {
             if (reply->len > 0)
             {
-                SW_ZVAL_STRINGL(return_value, reply->str, reply->len, 1);
+                ZVAL_STRINGL(return_value, reply->str, reply->len);
             }
             else
             {
@@ -659,20 +661,20 @@ static void swoole_redis_parse_result(swRedisClient *redis, zval* return_value,
         }
         else
         {
-            zend_update_property_long(swoole_redis_class_entry_ptr, redis->object, ZEND_STRL("errCode"), redis->context->err TSRMLS_CC);
-            zend_update_property_string(swoole_redis_class_entry_ptr, redis->object, ZEND_STRL("errMsg"), redis->context->errstr TSRMLS_CC);
+            zend_update_property_long(swoole_redis_class_entry_ptr, redis->object, ZEND_STRL("errCode"), redis->context->err);
+            zend_update_property_string(swoole_redis_class_entry_ptr, redis->object, ZEND_STRL("errMsg"), redis->context->errstr);
         }
         break;
 
     case REDIS_REPLY_STRING:
-        SW_ZVAL_STRINGL(return_value, reply->str, reply->len, 1);
+        ZVAL_STRINGL(return_value, reply->str, reply->len);
         break;
 
     case REDIS_REPLY_ARRAY:
         array_init(return_value);
         for (j = 0; j < reply->elements; j++)
         {
-            swoole_redis_parse_result(redis, val, reply->element[j] TSRMLS_CC);
+            swoole_redis_parse_result(redis, val, reply->element[j]);
             add_next_index_zval(return_value, val);
         }
         break;
@@ -687,12 +689,16 @@ static void swoole_redis_parse_result(swRedisClient *redis, zval* return_value,
 static void swoole_redis_onTimeout(swTimer *timer, swTimer_node *tnode)
 {
     swRedisClient *redis = tnode->data;
-    zend_update_property_long(swoole_redis_class_entry_ptr, redis->object, ZEND_STRL("errCode"), ETIMEDOUT TSRMLS_CC);
-    zend_update_property_string(swoole_redis_class_entry_ptr, redis->object, ZEND_STRL("errMsg"), strerror(ETIMEDOUT) TSRMLS_CC);
+    redis->timer = NULL;
+    zend_update_property_long(swoole_redis_class_entry_ptr, redis->object, ZEND_STRL("errCode"), ETIMEDOUT);
+    zend_update_property_string(swoole_redis_class_entry_ptr, redis->object, ZEND_STRL("errMsg"), strerror(ETIMEDOUT));
     redis->state = SWOOLE_REDIS_STATE_CLOSED;
-    redis_execute_connect_callback(redis, 0 TSRMLS_CC);
-    redisAsyncDisconnect(redis->context);
-    sw_zval_ptr_dtor(&redis->object);
+    redis_execute_connect_callback(redis, 0);
+    if (redis->context)
+    {
+        redisAsyncDisconnect(redis->context);
+    }
+    zval_ptr_dtor(redis->object);
 }
 
 static void swoole_redis_onCompleted(redisAsyncContext *c, void *r, void *privdata)
@@ -709,9 +715,9 @@ static void swoole_redis_onCompleted(redisAsyncContext *c, void *r, void *privda
         switch (reply->type)
         {
         case REDIS_REPLY_ERROR:
-            zend_update_property_long(swoole_redis_class_entry_ptr, redis->object, ZEND_STRL("errCode"), 0 TSRMLS_CC);
+            zend_update_property_long(swoole_redis_class_entry_ptr, redis->object, ZEND_STRL("errCode"), 0);
             zend_update_property_stringl(swoole_redis_class_entry_ptr, redis->object, ZEND_STRL("errMsg"), reply->str,
-                    reply->len TSRMLS_CC);
+                    reply->len);
             redis->failure = 1;
             break;
 
@@ -723,9 +729,9 @@ static void swoole_redis_onCompleted(redisAsyncContext *c, void *r, void *privda
             else
             {
                 zend_update_property_long(swoole_redis_class_entry_ptr, redis->object, ZEND_STRL("errCode"),
-                        redis->context->err TSRMLS_CC);
+                        redis->context->err);
                 zend_update_property_string(swoole_redis_class_entry_ptr, redis->object, ZEND_STRL("errMsg"),
-                        redis->context->errstr TSRMLS_CC);
+                        redis->context->errstr);
                 redis->failure = 1;
             }
             break;
@@ -737,20 +743,20 @@ static void swoole_redis_onCompleted(redisAsyncContext *c, void *r, void *privda
     {
         if (redis->failure)
         {
-            redis_execute_connect_callback(redis, 0 TSRMLS_CC);
+            redis_execute_connect_callback(redis, 0);
             redis->connecting = 0;
             zval *retval = NULL;
             zval *zobject = redis->object;
             sw_zend_call_method_with_0_params(&zobject, swoole_redis_class_entry_ptr, NULL, "close", &retval);
             if (retval)
             {
-                sw_zval_ptr_dtor(&retval);
+                zval_ptr_dtor(retval);
             }
             return;
         }
         else
         {
-            redis_execute_connect_callback(redis, 1 TSRMLS_CC);
+            redis_execute_connect_callback(redis, 1);
         }
     }
 }
@@ -769,7 +775,7 @@ static void swoole_redis_onResult(redisAsyncContext *c, void *r, void *privdata)
     zval *result, *retval, *callback;
     SW_MAKE_STD_ZVAL(result);
 
-    swoole_redis_parse_result(redis, result, reply TSRMLS_CC);
+    swoole_redis_parse_result(redis, result, reply);
 
     if (redis->state == SWOOLE_REDIS_STATE_SUBSCRIBE)
     {
@@ -789,23 +795,23 @@ static void swoole_redis_onResult(redisAsyncContext *c, void *r, void *privdata)
         }
     }
 
-    zval **args[2];
-    args[0] = &redis->object;
-    args[1] = &result;
+    zval args[2];
+    args[0] = *redis->object;
+    args[1] = *result;
 
-    if (sw_call_user_function_ex(EG(function_table), NULL, callback, &retval, 2, args, 0, NULL TSRMLS_CC) != SUCCESS)
+    if (sw_call_user_function_ex(EG(function_table), NULL, callback, &retval, 2, args, 0, NULL) != SUCCESS)
     {
         swoole_php_fatal_error(E_WARNING, "swoole_redis callback[%s] handler error.", callback_type);
     }
     if (EG(exception))
     {
-        zend_exception_error(EG(exception), E_ERROR TSRMLS_CC);
+        zend_exception_error(EG(exception), E_ERROR);
     }
     if (retval != NULL)
     {
-        sw_zval_ptr_dtor(&retval);
+        zval_ptr_dtor(retval);
     }
-    sw_zval_ptr_dtor(&result);
+    zval_ptr_dtor(result);
     if (!is_subscribe)
     {
         sw_zval_free(callback);
@@ -824,10 +830,10 @@ void swoole_redis_onConnect(const redisAsyncContext *c, int status)
 
     if (status != REDIS_OK)
     {
-        zend_update_property_long(swoole_redis_class_entry_ptr, redis->object, ZEND_STRL("errCode"), errno TSRMLS_CC);
-        zend_update_property_string(swoole_redis_class_entry_ptr, redis->object, ZEND_STRL("errMsg"), c->errstr TSRMLS_CC);
+        zend_update_property_long(swoole_redis_class_entry_ptr, redis->object, ZEND_STRL("errCode"), errno);
+        zend_update_property_string(swoole_redis_class_entry_ptr, redis->object, ZEND_STRL("errMsg"), c->errstr);
         redis->state = SWOOLE_REDIS_STATE_CLOSED;
-        redis_execute_connect_callback(redis, 0 TSRMLS_CC);
+        redis_execute_connect_callback(redis, 0);
         SwooleG.main_reactor->defer(SwooleG.main_reactor, redis_free_object, redis->object);
         return;
     }
@@ -849,7 +855,7 @@ void swoole_redis_onConnect(const redisAsyncContext *c, int status)
     }
     if (redis->wait_count == 0)
     {
-        redis_execute_connect_callback(redis, 1 TSRMLS_CC);
+        redis_execute_connect_callback(redis, 1);
     }
 }
 
@@ -859,33 +865,33 @@ void swoole_redis_onClose(const redisAsyncContext *c, int status)
     redis->state = SWOOLE_REDIS_STATE_CLOSED;
     redis->context = NULL;
 
-    zval *zcallback = sw_zend_read_property(swoole_redis_class_entry_ptr, redis->object, ZEND_STRL("onClose"), 1 TSRMLS_CC);
+    zval *zcallback = sw_zend_read_property(swoole_redis_class_entry_ptr, redis->object, ZEND_STRL("onClose"), 1);
     if (zcallback && !ZVAL_IS_NULL(zcallback))
     {
         zval *retval;
-        zval **args[1];
-        args[0] = &redis->object;
-        if (sw_call_user_function_ex(EG(function_table), NULL, zcallback, &retval, 1, args, 0, NULL TSRMLS_CC) != SUCCESS)
+        zval args[1];
+        args[0] = *redis->object;
+        if (sw_call_user_function_ex(EG(function_table), NULL, zcallback, &retval, 1, args, 0, NULL) != SUCCESS)
         {
             swoole_php_fatal_error(E_WARNING, "swoole_async_redis close_callback handler error.");
         }
         if (EG(exception))
         {
-            zend_exception_error(EG(exception), E_ERROR TSRMLS_CC);
+            zend_exception_error(EG(exception), E_ERROR);
         }
         if (retval != NULL)
         {
-            sw_zval_ptr_dtor(&retval);
+            zval_ptr_dtor(retval);
         }
     }
 
-    sw_zval_ptr_dtor(&redis->object);
+    zval_ptr_dtor(redis->object);
 }
 
 static int swoole_redis_onError(swReactor *reactor, swEvent *event)
 {
     swRedisClient *redis = event->socket->object;
-    zval *zcallback = sw_zend_read_property(swoole_redis_class_entry_ptr, redis->object, ZEND_STRL("onConnect"), 0 TSRMLS_CC);
+    zval *zcallback = sw_zend_read_property(swoole_redis_class_entry_ptr, redis->object, ZEND_STRL("onConnect"), 0);
 
     if (!ZVAL_IS_NULL(zcallback))
     {
@@ -893,29 +899,29 @@ static int swoole_redis_onError(swReactor *reactor, swEvent *event)
         zval *result;
         SW_MAKE_STD_ZVAL(result);
         ZVAL_BOOL(result, 0);
-        zend_update_property_long(swoole_redis_class_entry_ptr, redis->object, ZEND_STRL("errCode"), c->err TSRMLS_CC);
-        zend_update_property_string(swoole_redis_class_entry_ptr, redis->object, ZEND_STRL("errMsg"), c->errstr TSRMLS_CC);
+        zend_update_property_long(swoole_redis_class_entry_ptr, redis->object, ZEND_STRL("errCode"), c->err);
+        zend_update_property_string(swoole_redis_class_entry_ptr, redis->object, ZEND_STRL("errMsg"), c->errstr);
 
         redis->state = SWOOLE_REDIS_STATE_CLOSED;
 
         zval *retval = NULL;
-        zval **args[2];
-        args[0] = &redis->object;
-        args[1] = &result;
+        zval args[2];
+        args[0] = *redis->object;
+        args[1] = *result;
         redis->connecting = 1;
-        if (sw_call_user_function_ex(EG(function_table), NULL, zcallback, &retval, 2, args, 0, NULL TSRMLS_CC) != SUCCESS)
+        if (sw_call_user_function_ex(EG(function_table), NULL, zcallback, &retval, 2, args, 0, NULL) != SUCCESS)
         {
             swoole_php_fatal_error(E_WARNING, "swoole_async_redis connect_callback handler error.");
         }
         if (EG(exception))
         {
-            zend_exception_error(EG(exception), E_ERROR TSRMLS_CC);
+            zend_exception_error(EG(exception), E_ERROR);
         }
         if (retval != NULL)
         {
-            sw_zval_ptr_dtor(&retval);
+            zval_ptr_dtor(retval);
         }
-        sw_zval_ptr_dtor(&result);
+        zval_ptr_dtor(result);
 
         redis->connecting = 0;
         retval = NULL;
@@ -923,7 +929,7 @@ static int swoole_redis_onError(swReactor *reactor, swEvent *event)
         sw_zend_call_method_with_0_params(&zobject, swoole_redis_class_entry_ptr, NULL, "close", &retval);
         if (retval)
         {
-            sw_zval_ptr_dtor(&retval);
+            zval_ptr_dtor(retval);
         }
     }
     return SW_OK;
