@@ -75,6 +75,7 @@ static php_stream_ops socket_ops
     socket_stat,
     socket_set_option,
 };
+
 static bool hook_init = false;
 static int hook_flags;
 
@@ -82,23 +83,23 @@ static struct
 {
     php_stream_transport_factory tcp;
     php_stream_transport_factory udp;
-    php_stream_transport_factory unix;
+    php_stream_transport_factory _unix;
     php_stream_transport_factory udg;
 #ifdef SW_USE_OPENSSL
     php_stream_transport_factory ssl;
     php_stream_transport_factory tls;
 #endif
-} ori_factory =
-{ nullptr, nullptr, nullptr, nullptr,
+} ori_factory = {
+    nullptr,
+    nullptr,
+    nullptr,
+    nullptr,
 #ifdef SW_USE_OPENSSL
-        nullptr,
+    nullptr,
 #endif
-        };
+};
 
 static php_stream_wrapper ori_php_plain_files_wrapper;
-#if 0
-static php_stream_ops ori_php_stream_stdio_ops;
-#endif
 
 #if PHP_VERSION_ID < 70200
 typedef void (*zif_handler)(INTERNAL_FUNCTION_PARAMETERS);
@@ -125,11 +126,21 @@ static const zend_function_entry swoole_runtime_methods[] =
     PHP_FE_END
 };
 
-void swoole_runtime_init(int module_number TSRMLS_DC)
+void swoole_runtime_init(int module_number)
 {
     static zend_class_entry _ce;
     INIT_CLASS_ENTRY(_ce, "Swoole\\Runtime", swoole_runtime_methods);
-    ce = zend_register_internal_class(&_ce TSRMLS_CC);
+    ce = zend_register_internal_class(&_ce);
+
+    SWOOLE_DEFINE(HOOK_FILE);
+    SWOOLE_DEFINE(HOOK_SLEEP);
+    SWOOLE_DEFINE(HOOK_TCP);
+    SWOOLE_DEFINE(HOOK_UDP);
+    SWOOLE_DEFINE(HOOK_UNIX);
+    SWOOLE_DEFINE(HOOK_UDG);
+    SWOOLE_DEFINE(HOOK_SSL);
+    SWOOLE_DEFINE(HOOK_TLS);
+    SWOOLE_DEFINE(HOOK_ALL);
 }
 
 static auto block_io_functions =
@@ -340,6 +351,11 @@ static inline int socket_connect(php_stream *stream, Socket *sock, php_stream_xp
     int ret;
     char *ip_address = NULL;
 
+    if (sock->get_fd() < 0)
+    {
+        return -1;
+    }
+
     if (sock->type == SW_SOCK_TCP || sock->type == SW_SOCK_TCP6 || sock->type == SW_SOCK_UDP || sock->type == SW_SOCK_UDP6)
     {
         ip_address = parse_ip_address_ex(xparam->inputs.name, xparam->inputs.namelen, &portno, xparam->want_errortext,
@@ -777,7 +793,7 @@ static php_stream *socket_create(const char *proto, size_t protolen, const char
 
     if (unlikely(COROG.active == 0))
     {
-        coro_init(TSRMLS_C);
+        coro_init();
     }
 
     php_swoole_check_reactor();
@@ -822,7 +838,7 @@ static PHP_METHOD(swoole_runtime, enableCoroutine)
     zend_bool enable = 1;
     zend_long flags = SW_HOOK_ALL;
 
-    if (zend_parse_parameters(ZEND_NUM_ARGS()TSRMLS_CC, "|bl", &enable, &flags) == FAILURE)
+    if (zend_parse_parameters(ZEND_NUM_ARGS(), "|bl", &enable, &flags) == FAILURE)
     {
         RETURN_FALSE;
     }
@@ -841,10 +857,6 @@ static PHP_METHOD(swoole_runtime, enableCoroutine)
         {
             memcpy((void*) &ori_php_plain_files_wrapper, &php_plain_files_wrapper, sizeof(php_plain_files_wrapper));
             memcpy((void*) &php_plain_files_wrapper, &sw_php_plain_files_wrapper, sizeof(php_plain_files_wrapper));
-#if 0
-            memcpy((void*) &ori_php_stream_stdio_ops, &php_stream_stdio_ops, sizeof(php_stream_stdio_ops));
-            memcpy((void*) &php_stream_stdio_ops, &sw_php_stream_stdio_ops, sizeof(php_stream_stdio_ops));
-#endif
         }
         if (flags & SW_HOOK_SLEEP)
         {
@@ -880,17 +892,17 @@ static PHP_METHOD(swoole_runtime, enableCoroutine)
         }
         if (flags & SW_HOOK_UNIX)
         {
-            ori_factory.unix = (php_stream_transport_factory) zend_hash_str_find_ptr(xport_hash, ZEND_STRL("unix"));
+            ori_factory._unix = (php_stream_transport_factory) zend_hash_str_find_ptr(xport_hash, ZEND_STRL("unix"));
             php_stream_xport_register("unix", socket_create);
         }
         if (flags & SW_HOOK_UDG)
         {
-            ori_factory.unix = (php_stream_transport_factory) zend_hash_str_find_ptr(xport_hash, ZEND_STRL("udg"));
+            ori_factory._unix = (php_stream_transport_factory) zend_hash_str_find_ptr(xport_hash, ZEND_STRL("udg"));
             php_stream_xport_register("udg", socket_create);
         }
         if (flags & SW_HOOK_UDP)
         {
-            ori_factory.unix = (php_stream_transport_factory) zend_hash_str_find_ptr(xport_hash, ZEND_STRL("udp"));
+            ori_factory._unix = (php_stream_transport_factory) zend_hash_str_find_ptr(xport_hash, ZEND_STRL("udp"));
             php_stream_xport_register("udp", socket_create);
         }
 #ifdef SW_USE_OPENSSL
@@ -915,9 +927,6 @@ static PHP_METHOD(swoole_runtime, enableCoroutine)
         if (hook_flags & SW_HOOK_FILE)
         {
             memcpy((void*) &php_plain_files_wrapper, &ori_php_plain_files_wrapper, sizeof(php_plain_files_wrapper));
-#if 0
-            memcpy((void*) &php_stream_stdio_ops, &ori_php_stream_stdio_ops, sizeof(php_stream_stdio_ops));
-#endif
         }
         if (hook_flags & SW_HOOK_SLEEP)
         {
@@ -948,7 +957,7 @@ static PHP_METHOD(swoole_runtime, enableCoroutine)
         }
         if (flags & SW_HOOK_UNIX)
         {
-            php_stream_xport_register("unix", ori_factory.unix);
+            php_stream_xport_register("unix", ori_factory._unix);
         }
         if (flags & SW_HOOK_UDP)
         {
@@ -983,10 +992,16 @@ static PHP_FUNCTION(_sleep)
         php_error_docref(NULL, E_WARNING, "Number of seconds must be greater than or equal to 0");
         RETURN_FALSE;
     }
-    php_swoole_check_reactor();
-    php_swoole_check_timer(num * 1000);
-    swoole_coroutine_sleep((double) num);
-    RETURN_LONG(num);
+
+    if (num >= 0.001 && sw_coro_is_in())
+    {
+        php_swoole_check_reactor();
+        RETURN_LONG(swoole_coroutine_sleep((double) num) < 0 ? num : 0);
+    }
+    else
+    {
+        RETURN_LONG(php_sleep(num));
+    }
 }
 
 static PHP_FUNCTION(_usleep)
@@ -1001,9 +1016,17 @@ static PHP_FUNCTION(_usleep)
         php_error_docref(NULL, E_WARNING, "Number of seconds must be greater than or equal to 0");
         RETURN_FALSE;
     }
-    php_swoole_check_reactor();
-    php_swoole_check_timer(num / 1000);
-    swoole_coroutine_sleep((double) num / 1000000);
+    double _time = (double) num / 1000000;
+
+    if (_time >= 0.001 && sw_coro_is_in())
+    {
+        php_swoole_check_reactor();
+        swoole_coroutine_sleep((double) num / 1000000);
+    }
+    else
+    {
+        usleep((unsigned int)num);
+    }
 }
 
 static PHP_FUNCTION(_time_nanosleep)
@@ -1025,10 +1048,9 @@ static PHP_FUNCTION(_time_nanosleep)
         RETURN_FALSE;
     }
     double _time = (double) tv_sec + (double) tv_nsec / 1000000000.00;
-    if (_time >= 0.001)
+    if (_time >= 0.001 && sw_coro_is_in())
     {
         php_swoole_check_reactor();
-        php_swoole_check_timer(_time * 1000);
         swoole_coroutine_sleep(_time);
     }
     else
@@ -1085,10 +1107,9 @@ static PHP_FUNCTION(_time_sleep_until)
     php_req.tv_nsec = (long) ((c_ts - php_req.tv_sec) * 1000000000.00);
 
     double _time = (double) php_req.tv_sec + (double) php_req.tv_nsec / 1000000000.00;
-    if (_time >= 0.001)
+    if (_time >= 0.001 && sw_coro_is_in())
     {
         php_swoole_check_reactor();
-        php_swoole_check_timer(_time * 1000);
         swoole_coroutine_sleep(_time);
     }
     else
