@@ -46,8 +46,8 @@ ZEND_END_ARG_INFO()
 
 const zend_function_entry swoole_server_port_methods[] =
 {
-    PHP_ME(swoole_server_port, __construct,     arginfo_swoole_void, ZEND_ACC_PRIVATE | ZEND_ACC_CTOR)
-    PHP_ME(swoole_server_port, __destruct,      arginfo_swoole_void, ZEND_ACC_PUBLIC | ZEND_ACC_DTOR)
+    PHP_ME(swoole_server_port, __construct,     arginfo_swoole_void, ZEND_ACC_PRIVATE)
+    PHP_ME(swoole_server_port, __destruct,      arginfo_swoole_void, ZEND_ACC_PUBLIC)
     PHP_ME(swoole_server_port, set,             arginfo_swoole_server_port_set, ZEND_ACC_PUBLIC)
     PHP_ME(swoole_server_port, on,              arginfo_swoole_server_port_on, ZEND_ACC_PUBLIC)
 #ifdef SWOOLE_SOCKETS_SUPPORT
@@ -56,10 +56,10 @@ const zend_function_entry swoole_server_port_methods[] =
     PHP_FE_END
 };
 
-void swoole_server_port_init(int module_number TSRMLS_DC)
+void swoole_server_port_init(int module_number)
 {
     SWOOLE_INIT_CLASS_ENTRY(swoole_server_port_ce, "swoole_server_port", "Swoole\\Server\\Port", swoole_server_port_methods);
-    swoole_server_port_class_entry_ptr = zend_register_internal_class(&swoole_server_port_ce TSRMLS_CC);
+    swoole_server_port_class_entry_ptr = zend_register_internal_class(&swoole_server_port_ce);
     swoole_server_port_class_entry_ptr->serialize = zend_class_serialize_deny;
     swoole_server_port_class_entry_ptr->unserialize = zend_class_unserialize_deny;
     SWOOLE_CLASS_ALIAS(swoole_server_port, "Swoole\\Server\\Port");
@@ -69,24 +69,24 @@ void swoole_server_port_init(int module_number TSRMLS_DC)
         sw_zend_register_class_alias("Co\\Server\\Port", swoole_server_port_class_entry_ptr);
     }
 
-    zend_declare_property_null(swoole_server_port_class_entry_ptr, ZEND_STRL("onConnect"), ZEND_ACC_PUBLIC TSRMLS_CC);
-    zend_declare_property_null(swoole_server_port_class_entry_ptr, ZEND_STRL("onReceive"), ZEND_ACC_PUBLIC TSRMLS_CC);
-    zend_declare_property_null(swoole_server_port_class_entry_ptr, ZEND_STRL("onClose"), ZEND_ACC_PUBLIC TSRMLS_CC);
-    zend_declare_property_null(swoole_server_port_class_entry_ptr, ZEND_STRL("onPacket"), ZEND_ACC_PUBLIC TSRMLS_CC);
-    zend_declare_property_null(swoole_server_port_class_entry_ptr, ZEND_STRL("onBufferFull"), ZEND_ACC_PUBLIC TSRMLS_CC);
-    zend_declare_property_null(swoole_server_port_class_entry_ptr, ZEND_STRL("onBufferEmpty"), ZEND_ACC_PUBLIC TSRMLS_CC);
-    zend_declare_property_null(swoole_server_port_class_entry_ptr, ZEND_STRL("onRequest"), ZEND_ACC_PUBLIC TSRMLS_CC);
-    zend_declare_property_null(swoole_server_port_class_entry_ptr, ZEND_STRL("onHandShake"), ZEND_ACC_PUBLIC TSRMLS_CC);
-    zend_declare_property_null(swoole_server_port_class_entry_ptr, ZEND_STRL("onMessage"), ZEND_ACC_PUBLIC TSRMLS_CC);
-    zend_declare_property_null(swoole_server_port_class_entry_ptr, ZEND_STRL("onOpen"), ZEND_ACC_PUBLIC TSRMLS_CC);
+    zend_declare_property_null(swoole_server_port_class_entry_ptr, ZEND_STRL("onConnect"), ZEND_ACC_PUBLIC);
+    zend_declare_property_null(swoole_server_port_class_entry_ptr, ZEND_STRL("onReceive"), ZEND_ACC_PUBLIC);
+    zend_declare_property_null(swoole_server_port_class_entry_ptr, ZEND_STRL("onClose"), ZEND_ACC_PUBLIC);
+    zend_declare_property_null(swoole_server_port_class_entry_ptr, ZEND_STRL("onPacket"), ZEND_ACC_PUBLIC);
+    zend_declare_property_null(swoole_server_port_class_entry_ptr, ZEND_STRL("onBufferFull"), ZEND_ACC_PUBLIC);
+    zend_declare_property_null(swoole_server_port_class_entry_ptr, ZEND_STRL("onBufferEmpty"), ZEND_ACC_PUBLIC);
+    zend_declare_property_null(swoole_server_port_class_entry_ptr, ZEND_STRL("onRequest"), ZEND_ACC_PUBLIC);
+    zend_declare_property_null(swoole_server_port_class_entry_ptr, ZEND_STRL("onHandShake"), ZEND_ACC_PUBLIC);
+    zend_declare_property_null(swoole_server_port_class_entry_ptr, ZEND_STRL("onMessage"), ZEND_ACC_PUBLIC);
+    zend_declare_property_null(swoole_server_port_class_entry_ptr, ZEND_STRL("onOpen"), ZEND_ACC_PUBLIC);
 
-    zend_declare_property_null(swoole_server_port_class_entry_ptr, ZEND_STRL("host"), ZEND_ACC_PUBLIC TSRMLS_CC);
-    zend_declare_property_long(swoole_server_port_class_entry_ptr, ZEND_STRL("port"), 0, ZEND_ACC_PUBLIC TSRMLS_CC);
-    zend_declare_property_long(swoole_server_port_class_entry_ptr, ZEND_STRL("type"), 0, ZEND_ACC_PUBLIC TSRMLS_CC);
-    zend_declare_property_long(swoole_server_port_class_entry_ptr, ZEND_STRL("sock"), 0, ZEND_ACC_PUBLIC TSRMLS_CC);
-    zend_declare_property_null(swoole_server_port_class_entry_ptr, ZEND_STRL("setting"), ZEND_ACC_PUBLIC TSRMLS_CC);
+    zend_declare_property_null(swoole_server_port_class_entry_ptr, ZEND_STRL("host"), ZEND_ACC_PUBLIC);
+    zend_declare_property_long(swoole_server_port_class_entry_ptr, ZEND_STRL("port"), 0, ZEND_ACC_PUBLIC);
+    zend_declare_property_long(swoole_server_port_class_entry_ptr, ZEND_STRL("type"), 0, ZEND_ACC_PUBLIC);
+    zend_declare_property_long(swoole_server_port_class_entry_ptr, ZEND_STRL("sock"), 0, ZEND_ACC_PUBLIC);
+    zend_declare_property_null(swoole_server_port_class_entry_ptr, ZEND_STRL("setting"), ZEND_ACC_PUBLIC);
 
-    zend_declare_property_null(swoole_server_port_class_entry_ptr, ZEND_STRL("connections"), ZEND_ACC_PUBLIC TSRMLS_CC);
+    zend_declare_property_null(swoole_server_port_class_entry_ptr, ZEND_STRL("connections"), ZEND_ACC_PUBLIC);
 }
 
 static PHP_METHOD(swoole_server_port, __construct)
@@ -101,9 +101,8 @@ static PHP_METHOD(swoole_server_port, __destruct)
 
     swoole_server_port_property *property = swoole_get_property(getThis(), 0);
 
-#ifdef PHP_SWOOLE_ENABLE_FASTCALL
     int j;
-    for (j = 0; j < PHP_SERVER_CALLBACK_NUM; j++)
+    for (j = 0; j < PHP_SWOOLE_SERVER_PORT_CALLBACK_NUM; j++)
     {
         if (property->caches[j])
         {
@@ -111,7 +110,6 @@ static PHP_METHOD(swoole_server_port, __destruct)
             property->caches[j] = NULL;
         }
     }
-#endif
 
     efree(property);
     swoole_set_property(getThis(), 0, NULL);
@@ -124,7 +122,7 @@ static PHP_METHOD(swoole_server_port, set)
     HashTable *vht;
     zval *v;
 
-    if (zend_parse_parameters(ZEND_NUM_ARGS()TSRMLS_CC, "z", &zset) == FAILURE)
+    if (zend_parse_parameters(ZEND_NUM_ARGS(), "z", &zset) == FAILURE)
     {
         return;
     }
@@ -307,13 +305,13 @@ static PHP_METHOD(swoole_server_port, set)
         port->tcp_keepinterval = (uint16_t) Z_LVAL_P(v);
     }
     //tcp_keepcount
-    if (sw_zend_hash_find(vht, ZEND_STRS("tcp_keepcount"), (void **) &v) == SUCCESS)
+    if ((v = zend_hash_str_find(vht, ZEND_STRL("tcp_keepcount"))))
     {
         convert_to_long(v);
         port->tcp_keepcount = (uint16_t) Z_LVAL_P(v);
     }
     //tcp_fastopen
-    if (sw_zend_hash_find(vht, ZEND_STRS("tcp_fastopen"), (void **) &v) == SUCCESS)
+    if ((v = zend_hash_str_find(vht, ZEND_STRL("tcp_fastopen"))))
     {
         convert_to_boolean(v);
         port->tcp_fastopen = Z_BVAL_P(v);
@@ -352,7 +350,7 @@ static PHP_METHOD(swoole_server_port, set)
             }
 
             char *func_name = NULL;
-            if (!sw_zend_is_callable(v, 0, &func_name TSRMLS_CC))
+            if (!sw_zend_is_callable(v, 0, &func_name))
             {
                 swoole_php_fatal_error(E_ERROR, "function '%s' is not callable", func_name);
                 efree(func_name);
@@ -360,7 +358,7 @@ static PHP_METHOD(swoole_server_port, set)
             }
             efree(func_name);
             port->protocol.get_package_length = php_swoole_length_func;
-            sw_zval_add_ref(&v);
+            Z_TRY_ADDREF_P(v);
             port->protocol.private_data = sw_zval_dup(v);
             break;
         }
@@ -460,17 +458,17 @@ static PHP_METHOD(swoole_server_port, set)
             convert_to_boolean(v);
             port->ssl_config.prefer_server_ciphers = Z_BVAL_P(v);
         }
-        //    if (sw_zend_hash_find(vht, ZEND_STRS("ssl_session_tickets"), (void **) &v) == SUCCESS)
+        //    if ((v = zend_hash_str_find(vht, ZEND_STRL("ssl_session_tickets"))))
         //    {
         //        convert_to_boolean(v);
         //        port->ssl_config.session_tickets = Z_BVAL_P(v);
         //    }
-        //    if (sw_zend_hash_find(vht, ZEND_STRS("ssl_stapling"), (void **) &v) == SUCCESS)
+        //    if ((v = zend_hash_str_find(vht, ZEND_STRL("ssl_stapling"))))
         //    {
         //        convert_to_boolean(v);
         //        port->ssl_config.stapling = Z_BVAL_P(v);
         //    }
-        //    if (sw_zend_hash_find(vht, ZEND_STRS("ssl_stapling_verify"), (void **) &v) == SUCCESS)
+        //    if ((v = zend_hash_str_find(vht, ZEND_STRL("ssl_stapling_verify"))))
         //    {
         //        convert_to_boolean(v);
         //        port->ssl_config.stapling_verify = Z_BVAL_P(v);
@@ -502,7 +500,7 @@ static PHP_METHOD(swoole_server_port, set)
             }
             port->ssl_config.dhparam = sw_strdup(Z_STRVAL_P(v));
         }
-        //    if (sw_zend_hash_find(vht, ZEND_STRS("ssl_session_cache"), (void **) &v) == SUCCESS)
+        //    if ((v = zend_hash_str_find(vht, ZEND_STRL("ssl_session_cache"))))
         //    {
         //        convert_to_string(v);
         //        port->ssl_config.session_cache = strdup(Z_STRVAL_P(v));
@@ -515,9 +513,9 @@ static PHP_METHOD(swoole_server_port, set)
     }
 #endif
 
-    zval *zsetting = php_swoole_read_init_property(swoole_server_port_class_entry_ptr, getThis(), ZEND_STRL("setting") TSRMLS_CC);
-    sw_php_array_merge(Z_ARRVAL_P(zsetting), Z_ARRVAL_P(zset));
-    sw_zval_ptr_dtor(&zset);
+    zval *zsetting = sw_zend_read_property_array(swoole_server_port_class_entry_ptr, getThis(), ZEND_STRL("setting"), 1);
+    php_array_merge(Z_ARRVAL_P(zsetting), Z_ARRVAL_P(zset));
+    zval_ptr_dtor(zset);
 }
 
 static PHP_METHOD(swoole_server_port, on)
@@ -534,14 +532,14 @@ static PHP_METHOD(swoole_server_port, on)
         RETURN_FALSE;
     }
 
-    if (zend_parse_parameters(ZEND_NUM_ARGS()TSRMLS_CC, "sz", &name, &len, &cb) == FAILURE)
+    if (zend_parse_parameters(ZEND_NUM_ARGS(), "sz", &name, &len, &cb) == FAILURE)
     {
         return;
     }
 
     char *func_name = NULL;
     zend_fcall_info_cache *func_cache = emalloc(sizeof(zend_fcall_info_cache));
-    if (!sw_zend_is_callable_ex(cb, NULL, 0, &func_name, NULL, func_cache, NULL TSRMLS_CC))
+    if (!sw_zend_is_callable_ex(cb, NULL, 0, &func_name, NULL, func_cache, NULL))
     {
         swoole_php_fatal_error(E_ERROR, "function '%s' is not callable", func_name);
         efree(func_name);
@@ -549,28 +547,11 @@ static PHP_METHOD(swoole_server_port, on)
     }
     efree(func_name);
 
-    swListenPort *port = swoole_get_object(getThis());
-    if (!port->ptr)
-    {
-        port->ptr = property;
-    }
-
-    char *callback_name[PHP_SERVER_CALLBACK_NUM] = {
+    char *callback_name[PHP_SWOOLE_SERVER_PORT_CALLBACK_NUM] = {
         "Connect",
         "Receive",
         "Close",
         "Packet",
-        NULL, //onStart
-        NULL,
-        NULL,
-        NULL,
-        NULL,
-        NULL,
-        NULL,
-        NULL,
-        NULL,
-        NULL, //onManagerStop
-        NULL, //onPipeMessage
         "Request",
         "HandShake",
         "Open",
@@ -583,44 +564,46 @@ static PHP_METHOD(swoole_server_port, on)
     int l_property_name = 0;
     memcpy(property_name, "on", 2);
 
-    for (i = 0; i < PHP_SERVER_CALLBACK_NUM; i++)
+    for (i = 0; i < PHP_SWOOLE_SERVER_PORT_CALLBACK_NUM; i++)
     {
-        if (callback_name[i] == NULL)
+        if (strncasecmp(callback_name[i], name, len) != 0)
         {
             continue;
         }
-        if (strncasecmp(callback_name[i], name, len) == 0)
-        {
-            memcpy(property_name + 2, callback_name[i], len);
-            l_property_name = len + 2;
-            property_name[l_property_name] = '\0';
-            zend_update_property(swoole_server_port_class_entry_ptr, getThis(), property_name, l_property_name, cb TSRMLS_CC);
-            property->callbacks[i] = sw_zend_read_property(swoole_server_port_class_entry_ptr, getThis(), property_name, l_property_name, 0 TSRMLS_CC);
-            sw_copy_to_stack(property->callbacks[i], property->_callbacks[i]);
 
-            if (i == SW_SERVER_CB_onConnect && serv->onConnect == NULL)
-            {
-                serv->onConnect = php_swoole_onConnect;
-            }
-            else if (i == SW_SERVER_CB_onPacket && serv->onPacket == NULL)
-            {
-                serv->onPacket = php_swoole_onPacket;
-            }
-            else if (i == SW_SERVER_CB_onClose && serv->onClose == NULL)
-            {
-                serv->onClose = php_swoole_onClose;
-            }
-            else if (i == SW_SERVER_CB_onBufferFull && serv->onBufferFull == NULL)
-            {
-                serv->onBufferFull = php_swoole_onBufferFull;
-            }
-            else if (i == SW_SERVER_CB_onBufferEmpty && serv->onBufferEmpty == NULL)
-            {
-                serv->onBufferEmpty = php_swoole_onBufferEmpty;
-            }
-            property->caches[i] = func_cache;
-            break;
+        memcpy(property_name + 2, callback_name[i], len);
+        l_property_name = len + 2;
+        property_name[l_property_name] = '\0';
+        zend_update_property(swoole_server_port_class_entry_ptr, getThis(), property_name, l_property_name, cb);
+        property->callbacks[i] = sw_zend_read_property(swoole_server_port_class_entry_ptr, getThis(), property_name, l_property_name, 0);
+        sw_copy_to_stack(property->callbacks[i], property->_callbacks[i]);
+
+        if (i == SW_SERVER_CB_onConnect && serv->onConnect == NULL)
+        {
+            serv->onConnect = php_swoole_onConnect;
         }
+        else if (i == SW_SERVER_CB_onPacket && serv->onPacket == NULL)
+        {
+            serv->onPacket = php_swoole_onPacket;
+        }
+        else if (i == SW_SERVER_CB_onClose && serv->onClose == NULL)
+        {
+            serv->onClose = php_swoole_onClose;
+        }
+        else if (i == SW_SERVER_CB_onBufferFull && serv->onBufferFull == NULL)
+        {
+            serv->onBufferFull = php_swoole_onBufferFull;
+        }
+        else if (i == SW_SERVER_CB_onBufferEmpty && serv->onBufferEmpty == NULL)
+        {
+            serv->onBufferEmpty = php_swoole_onBufferEmpty;
+        }
+        else if (i == SW_SERVER_CB_onMessage || i == SW_SERVER_CB_onRequest)
+        {
+            serv->onReceive = php_swoole_http_onReceive;
+        }
+        property->caches[i] = func_cache;
+        break;
     }
 
     if (l_property_name == 0)
@@ -643,6 +626,6 @@ static PHP_METHOD(swoole_server_port, getSocket)
     }
     SW_ZEND_REGISTER_RESOURCE(return_value, (void *) socket_object, php_sockets_le_socket());
     zval *zsocket = sw_zval_dup(return_value);
-    sw_zval_add_ref(&zsocket);
+    Z_TRY_ADDREF_P(zsocket);
 }
 #endif
