@@ -25,10 +25,6 @@
 
 using namespace swoole;
 
-#ifdef FAST_ZPP
-#undef FAST_ZPP
-#endif
-
 static zend_class_entry swoole_socket_coro_ce;
 static zend_class_entry *swoole_socket_coro_class_entry_ptr;
 static zend_object_handlers swoole_socket_coro_handlers;
@@ -113,7 +109,7 @@ ZEND_END_ARG_INFO()
 
 static const zend_function_entry swoole_socket_coro_methods[] =
 {
-    PHP_ME(swoole_socket_coro, __construct, arginfo_swoole_socket_coro_construct, ZEND_ACC_PUBLIC | ZEND_ACC_CTOR)
+    PHP_ME(swoole_socket_coro, __construct, arginfo_swoole_socket_coro_construct, ZEND_ACC_PUBLIC)
     PHP_ME(swoole_socket_coro, bind, arginfo_swoole_socket_coro_bind, ZEND_ACC_PUBLIC)
     PHP_ME(swoole_socket_coro, listen, arginfo_swoole_socket_coro_listen, ZEND_ACC_PUBLIC)
     PHP_ME(swoole_socket_coro, accept, arginfo_swoole_socket_coro_accept, ZEND_ACC_PUBLIC)
@@ -146,10 +142,10 @@ static void swoole_socket_coro_free_storage(zend_object *object)
     zend_object_std_dtor(&sock->std);
 }
 
-static zend_object *swoole_socket_coro_create(zend_class_entry *ce TSRMLS_DC)
+static zend_object *swoole_socket_coro_create(zend_class_entry *ce)
 {
     socket_coro *sock = (socket_coro *) ecalloc(1, sizeof(socket_coro) + zend_object_properties_size(ce));
-    zend_object_std_init(&sock->std, ce TSRMLS_CC);
+    zend_object_std_init(&sock->std, ce);
     /* Even if you don't use properties yourself you should still call object_properties_init(),
      * because extending classes may use properties. (Generally a lot of the stuff you will do is
      * for the sake of not breaking extending classes). */
@@ -158,16 +154,16 @@ static zend_object *swoole_socket_coro_create(zend_class_entry *ce TSRMLS_DC)
     return &sock->std;
 }
 
-void swoole_socket_coro_init(int module_number TSRMLS_DC)
+void swoole_socket_coro_init(int module_number)
 {
     INIT_CLASS_ENTRY(swoole_socket_coro_ce, "Swoole\\Coroutine\\Socket", swoole_socket_coro_methods);
 
-    swoole_socket_coro_class_entry_ptr = zend_register_internal_class(&swoole_socket_coro_ce TSRMLS_CC);
+    swoole_socket_coro_class_entry_ptr = zend_register_internal_class(&swoole_socket_coro_ce);
     swoole_socket_coro_class_entry_ptr->ce_flags |= ZEND_ACC_FINAL;
     swoole_socket_coro_class_entry_ptr->create_object = swoole_socket_coro_create;
     swoole_socket_coro_class_entry_ptr->serialize = zend_class_serialize_deny;
     swoole_socket_coro_class_entry_ptr->unserialize = zend_class_unserialize_deny;
-    zend_declare_property_long(swoole_socket_coro_class_entry_ptr, SW_STRL("errCode") - 1, 0, ZEND_ACC_PUBLIC TSRMLS_CC);
+    zend_declare_property_long(swoole_socket_coro_class_entry_ptr, ZEND_STRL("errCode"), 0, ZEND_ACC_PUBLIC);
 
     memcpy(&swoole_socket_coro_handlers, zend_get_std_object_handlers(), sizeof(swoole_socket_coro_handlers));
     swoole_socket_coro_handlers.free_obj = swoole_socket_coro_free_storage;
@@ -176,7 +172,7 @@ void swoole_socket_coro_init(int module_number TSRMLS_DC)
 
     INIT_CLASS_ENTRY(swoole_socket_coro_exception_ce, "Swoole\\Coroutine\\Socket\\Exception", NULL);
     swoole_socket_coro_exception_class_entry_ptr = sw_zend_register_internal_class_ex(&swoole_socket_coro_exception_ce,
-            zend_exception_get_default(TSRMLS_C), NULL TSRMLS_CC);
+            zend_exception_get_default(), NULL);
 
     if (SWOOLE_G(use_shortname))
     {
@@ -189,18 +185,11 @@ static PHP_METHOD(swoole_socket_coro, __construct)
 {
     zend_long domain, type, protocol;
 
-#ifdef FAST_ZPP
     ZEND_PARSE_PARAMETERS_START(3, 3)
-        Z_PARAM_LONG(domain);
-        Z_PARAM_LONG(type);
-        Z_PARAM_LONG(protocol);
+        Z_PARAM_LONG(domain)
+        Z_PARAM_LONG(type)
+        Z_PARAM_LONG(protocol)
     ZEND_PARSE_PARAMETERS_END();
-#else
-    if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "lll", &domain, &type, &protocol) == FAILURE)
-    {
-        RETURN_FALSE;
-    }
-#endif
 
     php_swoole_check_reactor();
 
@@ -216,23 +205,16 @@ static PHP_METHOD(swoole_socket_coro, bind)
     size_t l_address;
     zend_long port = 0;
 
-#ifdef FAST_ZPP
     ZEND_PARSE_PARAMETERS_START(1, 2)
-        Z_PARAM_STRING(address, l_address);
+        Z_PARAM_STRING(address, l_address)
         Z_PARAM_OPTIONAL
-        Z_PARAM_LONG(port);
+        Z_PARAM_LONG(port)
     ZEND_PARSE_PARAMETERS_END();
-#else
-    if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "s|l", &address, &l_address, &port) == FAILURE)
-    {
-        RETURN_FALSE;
-    }
-#endif
 
     socket_coro *sock = (socket_coro *) Z_SOCKET_CORO_OBJ_P(getThis());
     if (!sock->socket->bind(std::string(address, l_address), port))
     {
-        zend_update_property_long(swoole_socket_coro_class_entry_ptr, getThis(), ZEND_STRL("errCode"), sock->socket->errCode TSRMLS_CC);
+        zend_update_property_long(swoole_socket_coro_class_entry_ptr, getThis(), ZEND_STRL("errCode"), sock->socket->errCode);
         RETURN_FALSE;
     }
     RETURN_TRUE;
@@ -242,22 +224,15 @@ static PHP_METHOD(swoole_socket_coro, listen)
 {
     zend_long backlog = SW_BACKLOG;
 
-#ifdef FAST_ZPP
     ZEND_PARSE_PARAMETERS_START(0, 1)
         Z_PARAM_OPTIONAL
-        Z_PARAM_LONG(backlog);
+        Z_PARAM_LONG(backlog)
     ZEND_PARSE_PARAMETERS_END();
-#else
-    if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "|l", &backlog) == FAILURE)
-    {
-        RETURN_FALSE;
-    }
-#endif
 
     socket_coro *sock = (socket_coro *) Z_SOCKET_CORO_OBJ_P(getThis());
     if (!sock->socket->listen(backlog))
     {
-        zend_update_property_long(swoole_socket_coro_class_entry_ptr, getThis(), ZEND_STRL("errCode"), sock->socket->errCode TSRMLS_CC);
+        zend_update_property_long(swoole_socket_coro_class_entry_ptr, getThis(), ZEND_STRL("errCode"), sock->socket->errCode);
         RETURN_FALSE;
     }
     RETURN_TRUE;
@@ -267,17 +242,10 @@ static PHP_METHOD(swoole_socket_coro, accept)
 {
     double timeout = -1;
 
-#ifdef FAST_ZPP
     ZEND_PARSE_PARAMETERS_START(0, 1)
         Z_PARAM_OPTIONAL
-        Z_PARAM_DOUBLE(timeout);
+        Z_PARAM_DOUBLE(timeout)
     ZEND_PARSE_PARAMETERS_END();
-#else
-    if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "|d", &timeout) == FAILURE)
-    {
-        RETURN_FALSE;
-    }
-#endif
 
     socket_coro *sock = (socket_coro *) Z_SOCKET_CORO_OBJ_P(getThis());
     if (timeout != 0)
@@ -294,30 +262,23 @@ static PHP_METHOD(swoole_socket_coro, accept)
     }
     else
     {
-        zend_update_property_long(swoole_socket_coro_class_entry_ptr, getThis(), ZEND_STRL("errCode"), sock->socket->errCode TSRMLS_CC);
+        zend_update_property_long(swoole_socket_coro_class_entry_ptr, getThis(), ZEND_STRL("errCode"), sock->socket->errCode);
         RETURN_FALSE;
     }
 }
 
 static PHP_METHOD(swoole_socket_coro, recv)
 {
-    coro_check(TSRMLS_C);
+    coro_check();
 
-    long length = SW_BUFFER_SIZE_BIG;
+    zend_long length = SW_BUFFER_SIZE_BIG;
     double timeout = -1;
 
-#ifdef FAST_ZPP
-    ZEND_PARSE_PARAMETERS_START(1, 2)
-        Z_PARAM_LONG(length);
+    ZEND_PARSE_PARAMETERS_START(0, 2)
         Z_PARAM_OPTIONAL
-        Z_PARAM_DOUBLE(timeout);
+        Z_PARAM_LONG(length)
+        Z_PARAM_DOUBLE(timeout)
     ZEND_PARSE_PARAMETERS_END();
-#else
-    if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "|ld", &length, &timeout) == FAILURE)
-    {
-        RETURN_FALSE;
-    }
-#endif
 
     if (length <= 0)
     {
@@ -331,7 +292,7 @@ static PHP_METHOD(swoole_socket_coro, recv)
     ssize_t bytes = sock->socket->recv(ZSTR_VAL(buf), length);
     if (bytes < 0)
     {
-        zend_update_property_long(swoole_socket_coro_class_entry_ptr, getThis(), ZEND_STRL("errCode"), sock->socket->errCode TSRMLS_CC);
+        zend_update_property_long(swoole_socket_coro_class_entry_ptr, getThis(), ZEND_STRL("errCode"), sock->socket->errCode);
         zend_string_free(buf);
         RETURN_FALSE;
     }
@@ -353,18 +314,11 @@ static PHP_METHOD(swoole_socket_coro, recvfrom)
     zval *peername;
     double timeout = -1;
 
-#ifdef FAST_ZPP
     ZEND_PARSE_PARAMETERS_START(1, 2)
-        Z_PARAM_ZVAL(peername);
+        Z_PARAM_ZVAL_EX(peername, 0, 1)
         Z_PARAM_OPTIONAL
-        Z_PARAM_DOUBLE(timeout);
+        Z_PARAM_DOUBLE(timeout)
     ZEND_PARSE_PARAMETERS_END();
-#else
-    if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "z/|d", &peername, &timeout) == FAILURE)
-    {
-        RETURN_FALSE;
-    }
-#endif
 
     socket_coro *sock = (socket_coro *) Z_SOCKET_CORO_OBJ_P(getThis());
     sock->socket->setTimeout(timeout);
@@ -373,7 +327,7 @@ static PHP_METHOD(swoole_socket_coro, recvfrom)
     ssize_t bytes = sock->socket->recvfrom(ZSTR_VAL(buf), SW_BUFFER_SIZE_BIG);
     if (bytes < 0)
     {
-        zend_update_property_long(swoole_socket_coro_class_entry_ptr, getThis(), ZEND_STRL("errCode"), sock->socket->errCode TSRMLS_CC);
+        zend_update_property_long(swoole_socket_coro_class_entry_ptr, getThis(), ZEND_STRL("errCode"), sock->socket->errCode);
         zend_string_free(buf);
         RETURN_FALSE;
     }
@@ -413,24 +367,17 @@ static PHP_METHOD(swoole_socket_coro, send)
     char *data;
     size_t l_data;
 
-#ifdef FAST_ZPP
     ZEND_PARSE_PARAMETERS_START(1, 2)
-        Z_PARAM_STRING(data, l_data);
+        Z_PARAM_STRING(data, l_data)
         Z_PARAM_OPTIONAL
-        Z_PARAM_DOUBLE(timeout);
+        Z_PARAM_DOUBLE(timeout)
     ZEND_PARSE_PARAMETERS_END();
-#else
-    if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "s|d", &data, &l_data, &timeout) == FAILURE)
-    {
-        RETURN_FALSE;
-    }
-#endif
 
     socket_coro *sock = (socket_coro *) Z_SOCKET_CORO_OBJ_P(getThis());
     ssize_t retval = sock->socket->send(data, l_data);
     if (retval < 0)
     {
-        zend_update_property_long(swoole_socket_coro_class_entry_ptr, getThis(), ZEND_STRL("errCode"), sock->socket->errCode TSRMLS_CC);
+        zend_update_property_long(swoole_socket_coro_class_entry_ptr, getThis(), ZEND_STRL("errCode"), sock->socket->errCode);
         RETURN_FALSE;
     }
     else
@@ -447,24 +394,17 @@ static PHP_METHOD(swoole_socket_coro, sendto)
     size_t l_addr;
     zend_long port = 0;
 
-#ifdef FAST_ZPP
     ZEND_PARSE_PARAMETERS_START(3, 3)
-        Z_PARAM_STRING(addr, l_addr);
-        Z_PARAM_LONG(port);
-        Z_PARAM_STRING(data, l_data);
+        Z_PARAM_STRING(addr, l_addr)
+        Z_PARAM_LONG(port)
+        Z_PARAM_STRING(data, l_data)
     ZEND_PARSE_PARAMETERS_END();
-#else
-    if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "sls", &addr, &l_addr, &port, &data, &l_data) == FAILURE)
-    {
-        RETURN_FALSE;
-    }
-#endif
 
     socket_coro *sock = (socket_coro *) Z_SOCKET_CORO_OBJ_P(getThis());
     ssize_t retval = sock->socket->sendto(addr, port, data, l_data);
     if (retval < 0)
     {
-        zend_update_property_long(swoole_socket_coro_class_entry_ptr, getThis(), ZEND_STRL("errCode"), sock->socket->errCode TSRMLS_CC);
+        zend_update_property_long(swoole_socket_coro_class_entry_ptr, getThis(), ZEND_STRL("errCode"), sock->socket->errCode);
         RETURN_FALSE;
     }
     else
@@ -475,13 +415,13 @@ static PHP_METHOD(swoole_socket_coro, sendto)
 
 static PHP_METHOD(swoole_socket_coro, close)
 {
-    coro_check(TSRMLS_C);
+    coro_check();
 
     socket_coro *sock = (socket_coro *) Z_SOCKET_CORO_OBJ_P(getThis());
 
-    if (sock->socket->close())
+    if (!sock->socket->close())
     {
-        zend_update_property_long(swoole_socket_coro_class_entry_ptr, getThis(), ZEND_STRL("errCode"), sock->socket->errCode TSRMLS_CC);
+        zend_update_property_long(swoole_socket_coro_class_entry_ptr, getThis(), ZEND_STRL("errCode"), sock->socket->errCode);
         RETURN_FALSE;
     }
     else
@@ -500,7 +440,7 @@ static PHP_METHOD(swoole_socket_coro, getsockname)
 
     if (getsockname(sock->socket->get_fd(), (struct sockaddr *) &info.addr.inet_v4, &info.len) != 0)
     {
-        zend_update_property_long(swoole_socket_coro_class_entry_ptr, getThis(), ZEND_STRL("errCode"), errno TSRMLS_CC);
+        zend_update_property_long(swoole_socket_coro_class_entry_ptr, getThis(), ZEND_STRL("errCode"), errno);
         RETURN_FALSE;
     }
 
@@ -535,7 +475,7 @@ static PHP_METHOD(swoole_socket_coro, getpeername)
 
     if (getpeername(sock->socket->get_fd(), (struct sockaddr *) &info.addr, &info.len) != 0)
     {
-        zend_update_property_long(swoole_socket_coro_class_entry_ptr, getThis(), ZEND_STRL("errCode"), errno TSRMLS_CC);
+        zend_update_property_long(swoole_socket_coro_class_entry_ptr, getThis(), ZEND_STRL("errCode"), errno);
         RETURN_FALSE;
     }
 
@@ -562,7 +502,7 @@ static PHP_METHOD(swoole_socket_coro, getpeername)
 
 static PHP_METHOD(swoole_socket_coro, connect)
 {
-    coro_check(TSRMLS_C);
+    coro_check();
 
     socket_coro *sock = (socket_coro *) Z_SOCKET_CORO_OBJ_P(getThis());
     char *host;
@@ -570,19 +510,12 @@ static PHP_METHOD(swoole_socket_coro, connect)
     zend_long port = 0;
     double timeout = SW_CLIENT_DEFAULT_TIMEOUT;
 
-#ifdef FAST_ZPP
     ZEND_PARSE_PARAMETERS_START(1, 3)
-        Z_PARAM_STRING(host, l_host);
+        Z_PARAM_STRING(host, l_host)
         Z_PARAM_OPTIONAL
-        Z_PARAM_LONG(port);
-        Z_PARAM_DOUBLE(timeout);
+        Z_PARAM_LONG(port)
+        Z_PARAM_DOUBLE(timeout)
     ZEND_PARSE_PARAMETERS_END();
-#else
-    if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "s|ld", &host, &l_host, &port, &timeout) == FAILURE)
-    {
-        RETURN_FALSE;
-    }
-#endif
 
     if (sock->domain == AF_INET6 || sock->domain == AF_INET)
     {
@@ -619,7 +552,7 @@ static PHP_METHOD(swoole_socket_coro, getSocket)
     }
     SW_ZEND_REGISTER_RESOURCE(return_value, (void * ) socket_object, php_sockets_le_socket());
     zval *zsocket = sw_zval_dup(return_value);
-    sw_zval_add_ref(&zsocket);
+    Z_TRY_ADDREF_P(zsocket);
     sock->resource = zsocket;
 }
 #endif
