@@ -33,7 +33,7 @@
 #include "thirdparty/swoole_http_parser.h"
 
 static zend_class_entry swoole_websocket_server_ce;
-static zend_class_entry *swoole_websocket_server_class_entry_ptr;
+zend_class_entry *swoole_websocket_server_class_entry_ptr;
 
 static zend_class_entry swoole_websocket_frame_ce;
 zend_class_entry *swoole_websocket_frame_class_entry_ptr;
@@ -43,7 +43,6 @@ static zend_class_entry *swoole_websocket_close_frame_class_entry_ptr;
 
 static int websocket_handshake(swListenPort *, http_context *);
 
-static PHP_METHOD(swoole_websocket_server, on);
 static PHP_METHOD(swoole_websocket_server, push);
 static PHP_METHOD(swoole_websocket_server, exist);
 static PHP_METHOD(swoole_websocket_server, isEstablished);
@@ -53,11 +52,6 @@ static PHP_METHOD(swoole_websocket_server, disconnect);
 
 static PHP_METHOD(swoole_websocket_frame, __toString);
 
-ZEND_BEGIN_ARG_INFO_EX(arginfo_swoole_websocket_server_on, 0, 0, 2)
-    ZEND_ARG_INFO(0, event_name)
-    ZEND_ARG_INFO(0, callback)
-ZEND_END_ARG_INFO()
-
 ZEND_BEGIN_ARG_INFO_EX(arginfo_swoole_websocket_server_push, 0, 0, 2)
     ZEND_ARG_INFO(0, fd)
     ZEND_ARG_INFO(0, data)
@@ -95,7 +89,6 @@ ZEND_END_ARG_INFO()
 
 const zend_function_entry swoole_websocket_server_methods[] =
 {
-    PHP_ME(swoole_websocket_server, on,             arginfo_swoole_websocket_server_on, ZEND_ACC_PUBLIC)
     PHP_ME(swoole_websocket_server, push,           arginfo_swoole_websocket_server_push, ZEND_ACC_PUBLIC)
     PHP_ME(swoole_websocket_server, disconnect,     arginfo_swoole_websocket_server_disconnect, ZEND_ACC_PUBLIC)
     PHP_ME(swoole_websocket_server, exist,          arginfo_swoole_websocket_server_exist, ZEND_ACC_PUBLIC)
@@ -138,13 +131,13 @@ static void php_swoole_websocket_construct_frame(zval *zframe, zend_long opcode,
     else
     {
         object_init_ex(zframe, swoole_websocket_frame_class_entry_ptr);
-        zend_update_property_stringl(swoole_websocket_frame_class_entry_ptr, zframe, ZEND_STRL("data"), payload, payload_length TSRMLS_CC);
+        zend_update_property_stringl(swoole_websocket_frame_class_entry_ptr, zframe, ZEND_STRL("data"), payload, payload_length);
     }
-    zend_update_property_bool(swoole_websocket_frame_class_entry_ptr, zframe, ZEND_STRL("finish"), finish TSRMLS_CC);
-    zend_update_property_long(swoole_websocket_frame_class_entry_ptr, zframe, ZEND_STRL("opcode"), opcode TSRMLS_CC);
+    zend_update_property_bool(swoole_websocket_frame_class_entry_ptr, zframe, ZEND_STRL("finish"), finish);
+    zend_update_property_long(swoole_websocket_frame_class_entry_ptr, zframe, ZEND_STRL("opcode"), opcode);
 }
 
-void sw_inline php_swoole_websocket_frame_unpack(swString *data, zval *zframe TSRMLS_DC)
+void php_swoole_websocket_frame_unpack(swString *data, zval *zframe)
 {
     swWebSocket_frame frame;
 
@@ -158,7 +151,7 @@ void sw_inline php_swoole_websocket_frame_unpack(swString *data, zval *zframe TS
     php_swoole_websocket_construct_frame(zframe, frame.header.OPCODE, frame.payload, frame.payload_length, frame.header.FIN);
 }
 
-int sw_inline php_swoole_websocket_frame_pack(swString *buffer, zval *zdata, zend_bool opcode, zend_bool fin, zend_bool mask)
+int php_swoole_websocket_frame_pack(swString *buffer, zval *zdata, zend_bool opcode, zend_bool fin, zend_bool mask)
 {
     char *data = NULL;
     size_t length = 0;
@@ -256,12 +249,12 @@ void swoole_websocket_onOpen(http_context *ctx)
         }
         else
         {
-            zval **args[2];
-            args[0] = &zserv;
-            args[1] = &zrequest_object;
+            zval args[2];
+            args[0] = *zserv;
+            args[1] = *zrequest_object;
 
             zval *zcallback = php_swoole_server_get_callback(SwooleG.serv, conn->from_fd, SW_SERVER_CB_onOpen);
-            if (sw_call_user_function_fast(zcallback, cache, &retval, 2, args TSRMLS_CC) == FAILURE)
+            if (sw_call_user_function_fast_ex(zcallback, cache, &retval, 2, args) == FAILURE)
             {
                 swoole_php_error(E_WARNING, "onOpen handler error");
             }
@@ -269,11 +262,11 @@ void swoole_websocket_onOpen(http_context *ctx)
 
         if (EG(exception))
         {
-            zend_exception_error(EG(exception), E_ERROR TSRMLS_CC);
+            zend_exception_error(EG(exception), E_ERROR);
         }
         if (retval)
         {
-            sw_zval_ptr_dtor(&retval);
+            zval_ptr_dtor(retval);
         }
     }
 }
@@ -295,7 +288,7 @@ void swoole_websocket_onRequest(http_context *ctx)
     swServer_tcp_send(SwooleG.serv, ctx->fd, bad_request, strlen(bad_request));
     ctx->end = 1;
     swServer_tcp_close(SwooleG.serv, ctx->fd, 0);
-    swoole_http_context_free(ctx TSRMLS_CC);
+    swoole_http_context_free(ctx);
 }
 
 void php_swoole_sha1(const char *str, int _len, unsigned char *digest)
@@ -312,9 +305,9 @@ static int websocket_handshake(swListenPort *port, http_context *ctx)
     HashTable *ht = Z_ARRVAL_P(header);
     zval *pData;
 
-    if (sw_zend_hash_find(ht, ZEND_STRS("sec-websocket-key"), (void **) &pData) == FAILURE)
+    if (!(pData = zend_hash_str_find(ht, ZEND_STRL("sec-websocket-key"))))
     {
-        php_error_docref(NULL TSRMLS_CC, E_WARNING, "header no sec-websocket-key");
+        php_error_docref(NULL, E_WARNING, "header no sec-websocket-key");
         return SW_ERR;
     }
     convert_to_string(pData);
@@ -380,7 +373,7 @@ int swoole_websocket_onMessage(swEventData *req)
     {
         if (!SwooleG.serv->listen_list->open_websocket_close_frame)
         {
-            sw_zval_ptr_dtor(&zdata);
+            zval_ptr_dtor(zdata);
             return SW_OK;
         }
     }
@@ -388,7 +381,7 @@ int swoole_websocket_onMessage(swEventData *req)
     zval *zframe;
     SW_MAKE_STD_ZVAL(zframe);
     php_swoole_websocket_construct_frame(zframe, opcode, Z_STRVAL_P(zdata), Z_STRLEN_P(zdata), finish);
-    zend_update_property_long(swoole_websocket_frame_class_entry_ptr, zframe, ZEND_STRL("fd"), fd TSRMLS_CC);
+    zend_update_property_long(swoole_websocket_frame_class_entry_ptr, zframe, ZEND_STRL("fd"), fd);
 
     swServer *serv = SwooleG.serv;
     zval *zserv = (zval *) serv->ptr2;
@@ -404,22 +397,22 @@ int swoole_websocket_onMessage(swEventData *req)
         int ret = coro_create(cache, args, 2, &retval, NULL, NULL);
         if (ret == CORO_LIMIT)
         {
-            sw_zval_ptr_dtor(&zdata);
-            sw_zval_ptr_dtor(&zframe);
+            zval_ptr_dtor(zdata);
+            zval_ptr_dtor(zframe);
             SwooleG.serv->factory.end(&SwooleG.serv->factory, fd);
             return SW_OK;
         }
     }
     else
     {
-        zval **args[2];
-        args[0] = &zserv;
-        args[1] = &zframe;
+        zval args[2];
+        args[0] = *zserv;
+        args[1] = *zframe;
 
         zend_fcall_info_cache *fci_cache = php_swoole_server_get_cache(serv, req->info.from_fd, SW_SERVER_CB_onMessage);
         zval *zcallback = php_swoole_server_get_callback(SwooleG.serv, req->info.from_fd, SW_SERVER_CB_onMessage);
 
-        if (sw_call_user_function_fast(zcallback, fci_cache, &retval, 2, args TSRMLS_CC) == FAILURE)
+        if (sw_call_user_function_fast_ex(zcallback, fci_cache, &retval, 2, args) == FAILURE)
         {
             swoole_php_error(E_WARNING, "onMessage handler error");
         }
@@ -427,14 +420,14 @@ int swoole_websocket_onMessage(swEventData *req)
 
     if (EG(exception))
     {
-        zend_exception_error(EG(exception), E_ERROR TSRMLS_CC);
+        zend_exception_error(EG(exception), E_ERROR);
     }
     if (retval)
     {
-        sw_zval_ptr_dtor(&retval);
+        zval_ptr_dtor(retval);
     }
-    sw_zval_ptr_dtor(&zdata);
-    sw_zval_ptr_dtor(&zframe);
+    zval_ptr_dtor(zdata);
+    zval_ptr_dtor(zframe);
     return SW_OK;
 }
 
@@ -454,32 +447,32 @@ int swoole_websocket_onHandshake(swListenPort *port, http_context *ctx)
     //free client data
     if (!ctx->end)
     {
-        swoole_http_context_free(ctx TSRMLS_CC);
+        swoole_http_context_free(ctx);
     }
 
     return SW_OK;
 }
 
-void swoole_websocket_init(int module_number TSRMLS_DC)
+void swoole_websocket_init(int module_number)
 {
     SWOOLE_INIT_CLASS_ENTRY(swoole_websocket_server_ce, "swoole_websocket_server", "Swoole\\WebSocket\\Server", swoole_websocket_server_methods);
-    swoole_websocket_server_class_entry_ptr = sw_zend_register_internal_class_ex(&swoole_websocket_server_ce, swoole_http_server_class_entry_ptr, "swoole_http_server" TSRMLS_CC);
+    swoole_websocket_server_class_entry_ptr = sw_zend_register_internal_class_ex(&swoole_websocket_server_ce, swoole_http_server_class_entry_ptr, "swoole_http_server");
     SWOOLE_CLASS_ALIAS(swoole_websocket_server, "Swoole\\WebSocket\\Server");
 
     SWOOLE_INIT_CLASS_ENTRY(swoole_websocket_frame_ce, "swoole_websocket_frame", "Swoole\\WebSocket\\Frame", swoole_websocket_frame_methods);
-    swoole_websocket_frame_class_entry_ptr = zend_register_internal_class(&swoole_websocket_frame_ce TSRMLS_CC);
+    swoole_websocket_frame_class_entry_ptr = zend_register_internal_class(&swoole_websocket_frame_ce);
     SWOOLE_CLASS_ALIAS(swoole_websocket_frame, "Swoole\\WebSocket\\Frame");
-    zend_declare_property_long(swoole_websocket_frame_class_entry_ptr, ZEND_STRL("fd"), 0, ZEND_ACC_PUBLIC TSRMLS_CC);
-    zend_declare_property_string(swoole_websocket_frame_class_entry_ptr, ZEND_STRL("data"), "", ZEND_ACC_PUBLIC TSRMLS_CC);
-    zend_declare_property_long(swoole_websocket_frame_class_entry_ptr, ZEND_STRL("opcode"), WEBSOCKET_OPCODE_TEXT, ZEND_ACC_PUBLIC TSRMLS_CC);
-    zend_declare_property_bool(swoole_websocket_frame_class_entry_ptr, ZEND_STRL("finish"), 1, ZEND_ACC_PUBLIC TSRMLS_CC);
+    zend_declare_property_long(swoole_websocket_frame_class_entry_ptr, ZEND_STRL("fd"), 0, ZEND_ACC_PUBLIC);
+    zend_declare_property_string(swoole_websocket_frame_class_entry_ptr, ZEND_STRL("data"), "", ZEND_ACC_PUBLIC);
+    zend_declare_property_long(swoole_websocket_frame_class_entry_ptr, ZEND_STRL("opcode"), WEBSOCKET_OPCODE_TEXT, ZEND_ACC_PUBLIC);
+    zend_declare_property_bool(swoole_websocket_frame_class_entry_ptr, ZEND_STRL("finish"), 1, ZEND_ACC_PUBLIC);
 
     SWOOLE_INIT_CLASS_ENTRY(swoole_websocket_close_frame_ce, "swoole_websocke_closet_frame", "Swoole\\WebSocket\\CloseFrame", NULL);
     swoole_websocket_close_frame_class_entry_ptr = zend_register_internal_class_ex(&swoole_websocket_close_frame_ce, swoole_websocket_frame_class_entry_ptr);
     SWOOLE_CLASS_ALIAS(swoole_websocket_close_frame, "Swoole\\WebSocket\\CloseFrame");
-    zend_declare_property_long(swoole_websocket_close_frame_class_entry_ptr, ZEND_STRL("opcode"), WEBSOCKET_OPCODE_CLOSE, ZEND_ACC_PUBLIC TSRMLS_CC);
-    zend_declare_property_long(swoole_websocket_close_frame_class_entry_ptr, ZEND_STRL("code"), WEBSOCKET_CLOSE_NORMAL, ZEND_ACC_PUBLIC TSRMLS_CC);
-    zend_declare_property_string(swoole_websocket_close_frame_class_entry_ptr, ZEND_STRL("reason"), "", ZEND_ACC_PUBLIC TSRMLS_CC);
+    zend_declare_property_long(swoole_websocket_close_frame_class_entry_ptr, ZEND_STRL("opcode"), WEBSOCKET_OPCODE_CLOSE, ZEND_ACC_PUBLIC);
+    zend_declare_property_long(swoole_websocket_close_frame_class_entry_ptr, ZEND_STRL("code"), WEBSOCKET_CLOSE_NORMAL, ZEND_ACC_PUBLIC);
+    zend_declare_property_string(swoole_websocket_close_frame_class_entry_ptr, ZEND_STRL("reason"), "", ZEND_ACC_PUBLIC);
 
     if (SWOOLE_G(use_shortname))
     {
@@ -516,57 +509,6 @@ void swoole_websocket_init(int module_number TSRMLS_DC)
     SWOOLE_RAW_DEFINE(WEBSOCKET_CLOSE_TLS);
 }
 
-static PHP_METHOD(swoole_websocket_server, on)
-{
-    zval *callback;
-    zval *event_name;
-
-    swServer *serv = swoole_get_object(getThis());
-    if (serv->gs->start > 0)
-    {
-        php_error_docref(NULL TSRMLS_CC, E_WARNING, "can't register event callback function after server started.");
-        RETURN_FALSE;
-    }
-
-    if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "zz", &event_name, &callback) == FAILURE)
-    {
-        return;
-    }
-
-    char *func_name = NULL;
-    zend_fcall_info_cache *func_cache = emalloc(sizeof(zend_fcall_info_cache));
-    if (!sw_zend_is_callable_ex(callback, NULL, 0, &func_name, NULL, func_cache, NULL TSRMLS_CC))
-    {
-        swoole_php_fatal_error(E_ERROR, "function '%s' is not callable", func_name);
-        efree(func_name);
-        RETURN_FALSE;
-    }
-    efree(func_name);
-
-    serv->listen_list->open_websocket_protocol = 1;
-
-    if (strncasecmp("open", Z_STRVAL_P(event_name), Z_STRLEN_P(event_name)) == 0)
-    {
-        zend_update_property(swoole_websocket_server_class_entry_ptr, getThis(), ZEND_STRL("onOpen"), callback TSRMLS_CC);
-        php_sw_server_callbacks[SW_SERVER_CB_onOpen] = sw_zend_read_property(swoole_websocket_server_class_entry_ptr, getThis(), ZEND_STRL("onOpen"), 0 TSRMLS_CC);
-        sw_copy_to_stack(php_sw_server_callbacks[SW_SERVER_CB_onOpen], _php_sw_server_callbacks[SW_SERVER_CB_onOpen]);
-        php_sw_server_caches[SW_SERVER_CB_onOpen] = func_cache;
-    }
-    else if (strncasecmp("message", Z_STRVAL_P(event_name), Z_STRLEN_P(event_name)) == 0)
-    {
-        zend_update_property(swoole_websocket_server_class_entry_ptr, getThis(), ZEND_STRL("onMessage"), callback TSRMLS_CC);
-        php_sw_server_callbacks[SW_SERVER_CB_onMessage] = sw_zend_read_property(swoole_websocket_server_class_entry_ptr, getThis(), ZEND_STRL("onMessage"), 0 TSRMLS_CC);
-        sw_copy_to_stack(php_sw_server_callbacks[SW_SERVER_CB_onMessage], _php_sw_server_callbacks[SW_SERVER_CB_onMessage]);
-        php_sw_server_caches[SW_SERVER_CB_onMessage] = func_cache;
-    }
-    else
-    {
-        efree(func_cache);
-        zval *obj = getThis();
-        sw_zend_call_method_with_2_params(&obj, swoole_http_server_class_entry_ptr, NULL, "on", &return_value, event_name, callback);
-    }
-}
-
 static sw_inline int swoole_websocket_server_push(int fd, swString *buffer)
 {
     if (unlikely(fd <= 0))
@@ -626,7 +568,7 @@ static PHP_METHOD(swoole_websocket_server, disconnect)
     char *data = NULL;
     size_t length = 0;
 
-    if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "l|ls", &fd, &code, &data, &length) == FAILURE)
+    if (zend_parse_parameters(ZEND_NUM_ARGS(), "l|ls", &fd, &code, &data, &length) == FAILURE)
     {
         RETURN_FALSE;
     }
@@ -645,7 +587,7 @@ static PHP_METHOD(swoole_websocket_server, push)
     zend_long opcode = WEBSOCKET_OPCODE_TEXT;
     zend_bool fin = 1;
 
-    if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "lz|lb", &fd, &zdata, &opcode, &fin) == FAILURE)
+    if (zend_parse_parameters(ZEND_NUM_ARGS(), "lz|lb", &fd, &zdata, &opcode, &fin) == FAILURE)
     {
         RETURN_FALSE;
     }
@@ -672,7 +614,7 @@ static PHP_METHOD(swoole_websocket_server, pack)
     zend_long opcode = WEBSOCKET_OPCODE_TEXT;
     zend_bool fin = 1;
     zend_bool mask = 0;
-    if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "z|lbb", &zdata, &opcode, &fin, &mask) == FAILURE)
+    if (zend_parse_parameters(ZEND_NUM_ARGS(), "z|lbb", &zdata, &opcode, &fin, &mask) == FAILURE)
     {
         return;
     }
@@ -707,12 +649,12 @@ static PHP_METHOD(swoole_websocket_server, unpack)
     swString buffer;
     bzero(&buffer, sizeof(buffer));
 
-    if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "s", &buffer.str, &buffer.length) == FAILURE)
+    if (zend_parse_parameters(ZEND_NUM_ARGS(), "s", &buffer.str, &buffer.length) == FAILURE)
     {
         return;
     }
 
-    php_swoole_websocket_frame_unpack(&buffer, return_value TSRMLS_CC);
+    php_swoole_websocket_frame_unpack(&buffer, return_value);
 }
 
 static PHP_METHOD(swoole_websocket_server, exist)
@@ -722,11 +664,11 @@ static PHP_METHOD(swoole_websocket_server, exist)
     swServer *serv = swoole_get_object(getThis());
     if (serv->gs->start == 0)
     {
-        php_error_docref(NULL TSRMLS_CC, E_WARNING, "the server is not running.");
+        php_error_docref(NULL, E_WARNING, "the server is not running.");
         RETURN_FALSE;
     }
 
-    if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "l", &fd) == FAILURE)
+    if (zend_parse_parameters(ZEND_NUM_ARGS(), "l", &fd) == FAILURE)
     {
         return;
     }
@@ -766,11 +708,11 @@ static PHP_METHOD(swoole_websocket_server, isEstablished)
     swServer *serv = swoole_get_object(getThis());
     if (serv->gs->start == 0)
     {
-        php_error_docref(NULL TSRMLS_CC, E_WARNING, "the server is not running.");
+        php_error_docref(NULL, E_WARNING, "the server is not running.");
         RETURN_FALSE;
     }
 
-    if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "l", &fd) == FAILURE)
+    if (zend_parse_parameters(ZEND_NUM_ARGS(), "l", &fd) == FAILURE)
     {
         return;
     }
